#ifndef __MC_3DCAMERA_H__
#define __MC_3DCAMERA_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QtOpenGL>

#include <QDebug>

class MC_3DCamera
{
protected:
        QVector3D m_position;       /*!< position */
        QVector3D m_interestPoint;  /*!< point toward the camera */
        QVector3D m_up;             /*!< up vector to orientate / flip camera */

public:

    MC_3DCamera(const QVector3D& position, const QVector3D& interestPoint, const QVector3D& up):m_position(position),m_interestPoint(interestPoint),m_up(up) {}
    virtual ~MC_3DCamera() {}

    virtual QVector3D position()const { return m_position; }
    virtual QVector3D interestPoint()const { return m_interestPoint; }
    virtual QVector3D up()const { return m_up; }

    virtual void apply()=0;

    void display();
};

QDebug operator<<(QDebug dbg, const MC_3DCamera& c);

/*! \class MC_3DCamera MC_3DCamera.h "3DRenderer/3DCamera/MC_3DCamera.h"
    \brief Base class for camera

    The camera is defined by 3 vectors:

    - position
    - direction (or interest point)
    - up

    The virtual pure function apply() allows to the sub classes to implement there own renderer specific code to apply the camera effect.
    The vectors determining the camera are all protected and can be changed by sub classes to allow movement of the camera.
 */

/*! \fn MC_3DCamera :: MC_3DCamera(const QVector3D& position, const QVector3D& interestPoint, const QVector3D& up)
    \param position
    \param interestPoint
    \param up
 */

/*! \fn virtual MC_3DCamera :: ~MC_3DCamera()
 */

/*! \fn virtual QVector3D MC_3DCamera :: position()const
    \brief The position of the camera
    \return
 */

/*! \fn virtual QVector3D MC_3DCamera :: interestPoint()const
    \brief The interest point of the camera
    \return
 */

/*! \fn virtual QVector3D MC_3DCamera :: up()const
    \brief The up vector of the camera
    \return
 */

/*! \fn virtual void MC_3DCamera :: apply()=0;
    \brief Apply the effect of the camera in the renderer
 */

/*! \fn void MC_3DCamera :: display();
    \brief display the camera information in the standart output
 */

/*! \fn QDebug operator<<(QDebug dbg, const MC_3DCamera& sc);
    \brief Writes the sc information (position, interestPoint and up vector), to the stream and returns a reference to the stream
 */

#endif
