/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "MC_3DSatelliteCamera.h"

#include "3DRenderer/MathUtils.h"

// Magic numbers for camera speed
#define ANGLE_STEP      0.2f
#define DISTANCE_STEP   0.02f

MC_3DSatelliteCamera :: MC_3DSatelliteCamera(float distance)
    :MC_3DQtCamera(
          QVector3D(0,0,-distance),
          QVector3D(0,0,0),
          QVector3D(0,1,0)),
      m_distance(distance),m_rotX(0),m_rotY(0)
{

}

void MC_3DSatelliteCamera :: setDistance(const float newDistance)
{
    m_distance = newDistance;

    if ( m_distance < minimumDistance )
    {
        m_distance = minimumDistance;
    }
    else if ( m_distance > maximumDistance )
    {
        m_distance = maximumDistance;
    }

    this->update();
}

void MC_3DSatelliteCamera :: update()
{
    m_position.setX(m_interestPoint.x() + (sin(MathUtils::degToRan(m_rotY)) * cos(MathUtils::degToRan(m_rotX))) * m_distance);
    m_position.setY(m_interestPoint.y() + sin(MathUtils::degToRan(m_rotX)) * m_distance);
    m_position.setZ(m_interestPoint.z() + (cos(MathUtils::degToRan(m_rotY)) * cos(MathUtils::degToRan(m_rotX))) * m_distance);
}

void MC_3DSatelliteCamera :: rotateAroundX(int nbSteps)
{
    if ( nbSteps == 0 )
    {
        return;
    }

    m_rotX += ANGLE_STEP * nbSteps;
    if ( m_rotX > 89.99f )
    {
        m_rotX = 89.99f;
    }
    if ( m_rotX < -89.99f )
    {
        m_rotX = -89.99f;
    }

    this->update();
}

void MC_3DSatelliteCamera :: rotateAroundY(int nbSteps)
{
    if ( nbSteps == 0 )
    {
        return;
    }

    m_rotY += ANGLE_STEP * nbSteps;

    this->update();
}

void MC_3DSatelliteCamera :: zoom(int nbSteps)
{
    if ( nbSteps == 0 )
    {
        return;
    }

    m_distance -= DISTANCE_STEP * nbSteps;
    if ( m_distance < minimumDistance )
    {
        m_distance = minimumDistance;
    }
    else if ( m_distance > maximumDistance )
    {
        m_distance = maximumDistance;
    }

    this->update();
}

QDebug operator<<(QDebug dbg, const MC_3DSatelliteCamera& sc)
{
    dbg << "Distance: " << sc.distance() << " RotationX: " << sc.rotX() << " RotationY: " << sc.rotY();
    dbg << "\n";

    dbg << "Position: " << sc.position();
    dbg << "Direction: " << sc.interestPoint();
    dbg << "Up: " << sc.up();

    return dbg.space();
}
