#ifndef __MC_3DSATELLITECAMERA_H__
#define __MC_3DSATELLITECAMERA_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "MC_3DQtCamera.h"

#include <QDebug>

class MC_3DSatelliteCamera : public MC_3DQtCamera
{    
private:

    // I know these lines are strangely not compiling on Ubuntu 10.04
    // The compiler error complain about the static float not possible
/*
    static const float angleStep = 0.1f;
    static const float distanceStep = 0.1f;
*/
    static const unsigned int minimumDistance = 1;      /*!< Minimum zoom distance */
    static const unsigned int maximumDistance = 300;    /*!< Maximum zoom distance */

protected:

    float m_distance;       /*!< Distance of the camera with the interest point */

    float m_rotX;           /*!< Rotation around the X axis */
    float m_rotY;           /*!< Rotation around the Y axis */

    void update();

public:

    MC_3DSatelliteCamera(float distance = 10);
    virtual ~MC_3DSatelliteCamera() {}

    virtual float distance()const { return m_distance; }
    virtual void setDistance(const float newDistance);

    virtual void rotateAroundX(int nbSteps);
    virtual void rotateAroundY(int nbSteps);

    virtual void zoom(int nbSteps);

    virtual float rotX()const { return m_rotX; }
    virtual float rotY()const { return m_rotY; }
};

QDebug operator<<(QDebug dbg, const MC_3DSatelliteCamera& sc);

/*! \class MC_3DSatelliteCamera MC_3DSatelliteCamera.h "3DRenderer/3DCamera/MC_3DSatelliteCamera.h"
    \brief Satellite camera implementation

    The camera rotates around the interest point. It can also zoom toward the object and unzoom
 */

/*! \fn MC_3DSatelliteCamera :: MC_3DSatelliteCamera(float distance = 10)
    \param distance distance to the interest point
    \see MC_3DSatelliteCamera :: setDistance
 */

/*! \fn float MC_3DSatelliteCamera :: distance()const
    \return
    \brief Return the distance between the interest point and the camera
    \see MC_3DSatelliteCamera :: setDistance
 */

/*! \fn void MC_3DSatelliteCamera :: setDistance(const float newDistance);
    \param newDistance
    \brief Set the distance of the camera with the interest point
    \see MC_3DSatelliteCamera :: distance
 */

/*! \fn void MC_3DSatelliteCamera :: rotateAroundX(int nbSteps);
    \param nbSteps number of steps to rotate around the X axis
    \brief Rotate of the number of steps around the X axis.
    nbSteps can be positive or negative. If it is negative, it will rotate in the counter order. If it is 0, it will do nothing.
    \see MC_3DSatelliteCamera :: rotateAroundX
 */

/*! \fn void MC_3DSatelliteCamera :: rotateAroundY(int nbSteps);
    \param nbSteps number of steps to rotate around the Y axis
    \brief Rotate of the number of steps around the Y axis.
    nbSteps can be positive or negative. If it is negative, it will rotate in the counter order. If it is 0, it will do nothing.
    \see MC_3DSatelliteCamera :: rotateAroundX
 */

/*! \fn void MC_3DSatelliteCamera :: zoom(int nbSteps);
    \param nbSteps number of steps to zoom in
    \brief Zoom towards the interest point
    nbSteps can be positive or negative. If it is negative, it will unzoom (move backwards). If it is 0, it will do nothing.
    \see MC_3DSatelliteCamera :: distance , MC_3DSatelliteCamera :: setDistance
 */

/*! \fn float MC_3DSatelliteCamera :: rotX()const
    \brief Get the rotation angle around X axis
    \return
 */

/*! \fn float MC_3DSatelliteCamera :: rotY()const
    \brief Get the rotation angle around Y axis
    \return
 */

/*! \fn void MC_3DSatelliteCamera :: update()
    \brief Updates the camera
 */


/*! \fn QDebug operator<<(QDebug dbg, const MC_3DSatelliteCamera& sc);
    \brief Writes the sc information (distance, rotations, position, interestPoint and up vector), to the stream and returns a reference to the stream
 */

#endif
