#ifndef __MC_3DSATELLITECAMERA2_H__
#define __MC_3DSATELLITECAMERA2_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "MC_3DSatelliteCamera.h"

#include <QDebug>

class MC_3DSatelliteCamera2 : public MC_3DSatelliteCamera
{    
protected:
    float m_rotZ;           /*!< Rotation around the Z axis */

public:

    MC_3DSatelliteCamera2(float distance = 10);

    void rotateAroundZ(int nbSteps);

    float rotZ()const { return m_rotZ; }

    void apply();
};

QDebug operator<<(QDebug dbg, const MC_3DSatelliteCamera2& sc);

/*! \class MC_3DSatelliteCamera2 MC_3DSatelliteCamera2.h "3DRenderer/3DCamera/MC_3DSatelliteCamera2.h"
    \brief Satellite camera implementation

    The camera rotates around the interest point. It can also zoom toward the object and unzoom.
    This implementation adds the Z axis rotation but is certainly affected by the Gimbal Lock
 */

/*! \fn MC_3DSatelliteCamera2 :: MC_3DSatelliteCamera2(float distance = 10)
    \param distance distance to the interest point
    \see MC_3DSatelliteCamera :: setDistance
 */

/*! \fn void MC_3DSatelliteCamera2 :: rotateAroundZ(int nbSteps);
    \param nbSteps number of steps to rotate around the Z axis
    \brief Rotate of the number of steps around the Z axis.
    nbSteps can be positive or negative. If it is negative, it will rotate in the counter order. If it is 0, it will do nothing.
    \see MC_3DSatelliteCamera :: rotateAroundX
 */

/*! \fn float MC_3DSatelliteCamera2 :: rotZ()const
    \brief Get the rotation angle around Z axis
    \return
 */



/*! \fn QDebug operator<<(QDebug dbg, const MC_3DSatelliteCamera2& sc);
    \brief Writes the sc information (distance, rotations, position, interestPoint and up vector), to the stream and returns a reference to the stream
 */

#endif
