#ifndef __MC_3DPARSER_H__
#define __MC_3DPARSER_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

class QString;
class QByteArray;

class MC_3DShapeModelList;

class MC_3DParser
{
protected:

    virtual bool parseData(const QByteArray& dataArray, MC_3DShapeModelList &shapeList, const QString& shapeName)=0;

public:

    virtual ~MC_3DParser() {}
    bool parse(const QString& fileName, MC_3DShapeModelList& shapeList);
    bool parse(const QByteArray& dataArray, MC_3DShapeModelList& shapeList, const QString& shapeName);
};

/*! \class MC_3DParser MC_3DParser.h "3DRenderer/3DParser/MC_3DParser.h"
    \brief Virtual class for 3D file parsers

    Implements the function to parse the file and put the data in the 3DRendererModel
 */

/*! \fn virtual MC_3DParser::~MC_3DParser()=0;
 */

/*! \fn virtual bool MC_3DParser :: parseData(const QByteArray& dataArray, MC_3DShapeModelList &shapeList, const QString& shapeName)=0
    \brief Parse a shape from a QByteArray to put it in a list
    \param dataArray the data to parse
    \param shapeList the list to fill
    \param shapeName the name of the new shape
    \return true if all goes right
 */

/*! \fn virtual bool MC_3DParser::parse(const QString& fileName, MC_3DShapeModelList& shapeList)=0;
    \brief Reads a file to extract the information about a 3D shape
    \param fileName the path to the file to read from
    \param shapeList the list of shapes where to put the new shape
    \return true if all goes right ; false if the file is not open or not correctly formatted
 */

/*! \fn bool MC_3DParser :: parse(const QByteArray& dataArray, MC_3DShapeModelList& shapeList, const QString& shapeName)
    \brief Parse a shape from a QByteArray
    \param dataArray the data to read
    \param shapeList the list to fill
    \param shapeName the name of the new shape
  */

#endif
