/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "MC_Trian3DParser.h"

#include <QString>

#include "../../MC_3DShapeModelList.h"
#include "../../MC_3DShape.h"

MC_Trian3DParser :: MC_Trian3DParser()
{
    m_colourMap["artery"] = QColor::fromRgbF(1,0.101961,0.101961);
    m_colourMap["bone"] = QColor::fromRgbF(0.94902,0.94902,0.85098);
    m_colourMap["kydney"] = QColor::fromRgbF(0.501961,0.2,0.101961);
    m_colourMap["liver"] = QColor::fromRgbF(0.8,0.2,0.2);
    m_colourMap["lung"] = QColor::fromRgbF(1,0.8,0.901961);
    m_colourMap["pancreas"] = QColor::fromRgbF(1,0.701961,0.4);
    m_colourMap["portalvein"] = QColor::fromRgbF(0,0,1);
    m_colourMap["skin"] = QColor::fromRgbF(1,0.701961,0.54902);
    m_colourMap["spleen"] = QColor::fromRgbF(0.6,0.101961,0.301961);
    m_colourMap["stomach"] = QColor::fromRgbF(0.6,0.6,1);
    m_colourMap["leftsurrenalgland"] = QColor::fromRgbF(1,0.6,0.301961);
    m_colourMap["tumorleftsurrenalgland"] = QColor::fromRgbF(1,0,0);
    m_colourMap["rightsurrenalgland"] = QColor::fromRgbF(1,0.6,0.301961);
    m_colourMap["venoussystem"] = QColor::fromRgbF(0.2,0.4,1);
}

bool MC_Trian3DParser :: parseData(const QByteArray& data, MC_3DShapeModelList& shapeList, const QString& shapeName)
{
    MC_3DShape shape;
    QTextStream dataStream(data);
    unsigned int numberVertices = 0;
    dataStream >> numberVertices;
    if ( numberVertices == 0 )
    {
        qDebug() << "Fail to read the number of vertices in the file, or invalid number (0)";
        return false;
    }

    shape.reserveVerticesMemory(numberVertices);

    // Reading of vertices
    for ( unsigned int i = 0 ; i < numberVertices ; i++ )
    {
        if ( dataStream.atEnd() )
        {
            qDebug() << "Unexpected end of file";
            return false;
        }

        qreal vx,vy,vz;
        dataStream >> vx >> vy >> vz;

        shape.addVertex(QVector3D(vx,vy,vz));
    }

    // Reading number of indices
    unsigned int numberIndices = 0;
    dataStream >> numberIndices;
    if ( numberIndices == 0 )
    {
        qDebug() << "Fail to read the number of vertices in the file, or invalid number (0)";
        return false;
    }

    shape.reserveIndicesMemory(numberIndices * 3);

    // Reading of indices
    for ( unsigned int i = 0 ; i < numberIndices ; i++ )
    {
        if ( dataStream.atEnd() )
        {
            qDebug() << "Unexpected end of file";
            return false;
        }

        unsigned int i1,i2,i3;
        int trash1,trash2,trash3;
        dataStream >> i1 >> i2 >> i3 >> trash1 >> trash2 >> trash3;

        shape.addIndex(i1);
        shape.addIndex(i2);
        shape.addIndex(i3);
    }

    // Since the file does not have the normals, we generate these
    shape.generateNormals();

    // Set the colour from the table (name as identifier)
    for ( QMap<QString, QColor>::const_iterator itPair = m_colourMap.begin() ;
          itPair != m_colourMap.end() ;
          ++itPair )
    {
        if ( shapeName.contains(itPair.key(),Qt::CaseInsensitive))
        {
            shape.setColour(itPair.value());
        }
    }

    // So, all looks fine, we add the shape in the renderer model
    return shapeList.addShape(shapeName,shape);
}
