#ifndef __MC_TRIAN3DPARSER_H__
#define __MC_TRIAN3DPARSER_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "../MC_3DParser.h"

#include <QMap>
#include <QString>
#include <QColor>

class QByteArray;

class MC_3DShapeModelList;

class MC_Trian3DParser : public MC_3DParser
{
private:

    QMap<QString, QColor> m_colourMap;  /*!< */

protected:

    bool parseData(const QByteArray& data, MC_3DShapeModelList& shapeList, const QString& shapeName);

public:

    MC_Trian3DParser();
    ~MC_Trian3DParser() {}
};

/*! \class MC_Trian3DParser MC_Trian3DParser.h "3DRenderer/3DParser/trian/MC_Trian3DParser.h"
    \brief 3DParser implementation to read the .trian files
    The parser has a colour map hard coded, giving colours to shapes based on the shape's name
    If the shape's name is not found, a colour is randomly generated

    .trian files are composed as following:
        - number of vertices
        - vx vy vz
        - .
        - . * (number of vertices)
        - .
        - number of indices
        - i1 i2 i3 -1 -1 -1
        - .
        - . * (number of indices)
        - .
 */

/*! \fn MC_Trian3DParser :: MC_Trian3DParser()
 */

/*! \fn MC_Trian3DParser :: ~MC_Trian3DParser()
 */

/*! \fn bool MC_Trian3DParser :: parseData(const QByteArray& data, MC_3DShapeModelList& shapeList, const QString& shapeName)
 *  \brief Parse data to construct a new shape stored in shapeList
 *  \param data the data to parse
 *  \param shapeList the list of shapes where to add the new shape
 *  \param shapeName the name of the new shape
 *  \return true if all goes right
 */

#endif
