/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "MC_3DShader.h"

#include <QGLShaderProgram>

#include <QFile>

#include <QDebug>

bool MC_3DShader :: loadShaderFiles(const QString& vertexShaderFile, const QString& fragmentShaderFile)
{
    bool bResult = true;
    if ( QFile::exists(vertexShaderFile) == false )
    {
        qDebug() << "The file '" << vertexShaderFile << "' does not exist";
        return false;
    }
    if ( QFile::exists(fragmentShaderFile) == false )
    {
        qDebug() << "The file '" << fragmentShaderFile << "' does not exist";
        return false;
    }

    this->removeAllShaders();

    bResult &= this->addShaderFromSourceFile(QGLShader::Vertex, vertexShaderFile);
    if ( bResult == false )
    {
        qDebug() << "Vertex shader compilation failed: " << this->log();
        return false;
    }

    bResult &= this->addShaderFromSourceFile(QGLShader::Fragment, fragmentShaderFile);
    if ( bResult == false )
    {
        qDebug() << "Fragment shader compilation failed: " << this->log();
        return false;
    }

    bResult &= this->link();
    if ( bResult == false )
    {
        qDebug() << "Shader link failed: " << this->log();
    }

    return true;
}

#ifndef QT_NO_DEBUG
void MC_3DShader :: setUniformValue(const char *name, const QMatrix4x4 &value)
{
    if ( this->uniformLocation(name) == -1 )
    {
        qDebug() << "Uniform '" << name << "' not found or unused";
    }

    QGLShaderProgram::setUniformValue(name,value);
}

void MC_3DShader :: setUniformValue(const char *name, const QVector3D &value)
{
    if ( this->uniformLocation(name) == -1 )
    {
        qDebug() << "Uniform '" << name << "' not found or unused";
    }

    QGLShaderProgram::setUniformValue(name,value);
}

void MC_3DShader :: setUniformValue(const char *name, const QColor &value)
{
    if ( this->uniformLocation(name) == -1 )
    {
        qDebug() << "Uniform '" << name << "' not found or unused";
    }

    QGLShaderProgram::setUniformValue(name,value);
}
#endif
