/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "MC_3DGLShape.h"

#include <QGLBuffer>

#include <cassert>

#include "MC_3DShape.h"

MC_3DGLShape :: MC_3DGLShape()
    :m_verticesBuffer(QGLBuffer::VertexBuffer),
     m_normalsBuffer(QGLBuffer::VertexBuffer),
     m_indicesBuffer(QGLBuffer::IndexBuffer)
{

}

bool MC_3DGLShape :: createBuffer(QGLBuffer* const pBuffer, const void* data, int count)
{
    assert(pBuffer);
    assert(data);

    bool bResult = true;

    bResult &= pBuffer->create();
    bResult &= pBuffer->bind();
    pBuffer->allocate(data,count);
    pBuffer->release();

    return bResult;
}

bool MC_3DGLShape :: loadShape(const MC_3DShape& shape)
{
    bool bResult = true;

    bResult &= this->createBuffer(&m_verticesBuffer,shape.getVertices().constData(), shape.getVerticesDataSize());
    if ( bResult == false )
    {
        qDebug() << "Fail to allocate vertex buffer";
        return false;
    }

    bResult &= this->createBuffer(&m_normalsBuffer,shape.getNormals().constData(), shape.getNormalsDataSize());
    if ( bResult == false )
    {
        qDebug() << "Fail to allocate normal buffer";
        return false;
    }

    bResult &= this->createBuffer(&m_indicesBuffer,shape.getIndices().constData(), shape.getIndicesDataSize());
    if ( bResult == false )
    {
        qDebug() << "Fail to allocate index buffer";
        return false;
    }

    m_nbIndices = shape.getIndicesNumber();

    return true;
}

void MC_3DGLShape :: draw()
{
    m_verticesBuffer.bind();
    glVertexPointer(3, GL_FLOAT, 0, NULL);
    m_verticesBuffer.release();

    m_normalsBuffer.bind();
    glNormalPointer(GL_FLOAT, 0, NULL);
    m_normalsBuffer.release();

    m_indicesBuffer.bind();
    glDrawElements(GL_TRIANGLES, m_nbIndices, GL_UNSIGNED_INT, NULL);
    m_indicesBuffer.release();
}
