#ifndef __MC_3DGLSHAPE_H__
#define __MC_3DGLSHAPE_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "QGLBuffer"

class MC_3DShape;

class MC_3DGLShape
{
private:

    QGLBuffer m_verticesBuffer; /*!< */
    QGLBuffer m_normalsBuffer;  /*!< */
    QGLBuffer m_indicesBuffer;  /*!< */

    unsigned int m_nbIndices;   /*!< */

    bool createBuffer(QGLBuffer* const pBuffer, const void* data, int count);

public:

    MC_3DGLShape();

    bool loadShape(const MC_3DShape& shape);
    void draw();
};

/*! \class MC_3DGLShape MC_3DGLShape.h "3DRenderer/MC_3DGLShape.h"
    \brief OpenGL instance of a shape

    The class store all the OpenGL data that needs a shape to be drawn. The technique use to render shapes is based on Vertex Buffer Objects (VBO)
 */

/*! \fn MC_3DGLShape :: MC_3DGLShape()
 */

/*! \fn bool MC_3DGLShape :: createBuffer(QGLBuffer* const pBuffer, const void* data, int count)
    \brief Commodity function to create a new buffer and to copy data in
    \param pBuffer pointer on the buffer to create
    \param data the data to copy on GPU
    \param count the amount of memory in bytes to allocate and copy
    The function is just a shortcut for the sequence create / bind / allocate / release
 */

/*! \fn bool MC_3DGLShape :: loadShape(const MC_3DShape& shape)
    \brief Loads a MC_3DShape into OpenGL
    \param shape the shape to load
    \return true if all goes right; false if buffers creation failed
    The function will allocate GPU memory to store the vertex/index data
 */

/*! \fn void MC_3DGLShape :: draw();
    \brief Draws the buffers available
 */

#endif
