#ifndef __MC_3DRENDERERGL_H__
#define __MC_3DRENDERERGL_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QtOpenGL/QGLBuffer>

#include "MC_3DRenderer.h"

class MC_3DShapeModelList;

class MC_3DRendererGL : public MC_3DRenderer
{
private:

public:

    explicit MC_3DRendererGL();
    ~MC_3DRendererGL();

    bool initScene();
    bool draw(MC_3DShapeModelList& model);
};

/*! \class MC_3DRenderer MC_3DRenderer.h "3DRenderer/MC_3DRenderer.h"
    \brief Display the data from a MC_3DRendererModel

    The class assembles the different 3D element to get the scene rendered on screen.
    It uses a camera, a shader and reads data from the MC_3DRendererModel to display it. The class manage the projection matrix through resizeScene()
 */

/*! \fn MC_3DRenderer :: MC_3DRenderer()
 */

/*! \fn MC_3DRenderer :: ~MC_3DRenderer()
 */

/*! \fn bool MC_3DRenderer :: initScene()
    \brief applies the initialisation of the renderer (loading basic shaders, setting rendering states)
    \return true if all goes right
 */

/*! \fn bool MC_3DRenderer :: draw(MC_3DShapeModelList& model)
    \brief draws the scene
    \param model the scene to render
    \return true if all goes right
 */

/*! \fn void resizeScene(int width, int height);
    \brief Changes the size of the render area
    \param width the width of the new render area
    \param height the height of the new render area
    Note: it will also update the projection matrix to keep a correct ratio
 */

/*! \fn const MC_3DSatelliteCamera& MC_3DRenderer :: camera()const
    \brief Gets the camera
    \return
    \see MC_3DRenderer :: setCamera
 */

/*! \fn void MC_3DRenderer :: setCamera(const MC_3DSatelliteCamera& camera);
    \brief Set a new camera
    \param camera
    \see MC_3DRenderer :: camera
 */

/*! \fn bool MC_3DRenderer :: loadShaderFiles(const QString& vertexShaderFile, const QString& fragmentShaderFile);
    \brief Load svertex and fragment shader
    \param vertexShaderFile the path to the vertex shader file
    \param fragmentShaderFile the path to the fragment shader file
    \return true if all goes right
    \see MC_3DShader::loadShaderFiles()
 */

#endif
