#ifndef __MC_3DSHAPEMODEL_H__
#define __MC_3DSHAPEMODEL_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QString>
#include <QColor>

#include "MC_3DShape.h"
#include "MC_3DGLShape.h"

class MC_3DShapeModel
{
protected:

    MC_3DShape m_shape;         /*!< */

    bool m_isEnabled;           /*!< */

    QString m_name;             /*!< */

public:

    MC_3DShapeModel();

    virtual bool loadShape(const QString& name, const MC_3DShape& shape)=0;
    virtual void draw()=0;

    bool enabled()const { return m_isEnabled; }
    void setEnabled(bool newState) { m_isEnabled = newState; }

    const QString& name()const { return m_name; }
    void setName(const QString& name) { m_name = name; }

    const QColor& colour()const { return m_shape.colour(); }
    void setColour(const QColor& colour) { m_shape.setColour(colour); }

    const QVector3D& minPoint()const { return m_shape.minPoint(); }
    const QVector3D& maxPoint()const { return m_shape.maxPoint(); }

    const MC_3DShape* get3DShape()const { return &m_shape; }
};

/*! \class MC_3DShapeModel MC_3DShapeModel.h "3DRenderer/MC_3DShapeModel.h"
    \brief Model for a 3D shape

    In this implementation of the MV(C) the MC_3DShapeModel is the model for the MC_3DRenderer.
    To complete this, the MC_3DShapeModel contains a MC_3DShape and the equivalent MC_3DGLShape used for rendering.
    Additionnals information as the name or if the shape is enabled have been integrated
 */

/*! \fn MC_3DShapeModel :: MC_3DShapeModel()
 */

/*! \fn bool MC_3DShapeModel :: loadShape(const QString& name, const MC_3DShape& shape);
    \brief Loads a shape in the model
    \param name name of the shape to be recognised
    \param shape
    \return true if all goes right; false if something failed during the creation of MC_3DGLShape
    The name exists to let the user to determine if the shape is already loaded.
    By default, if all is properly loaded, the shape is enabled
 */

/*! \fn void MC_3DShapeModel :: draw();
    \brief draw the shape using MC_3DGLShape
 */

/*! \fn bool MC_3DShapeModel :: enabled()const;
    \brief Returns if the shape is enabled
    \return
 */

/*! \fn void MC_3DShapeModel :: setEnabled(bool newState);
    \brief if newState is true, the shape will be enabled; otherwise the shape is not
 */

/*! \fn const QString& MC_3DShapeModel :: name()const;
    \brief Returns the name
    \return
 */

/*! \fn void MC_3DShapeModel :: setName(const QString& name);
 *  \brief Sets the name of the shape
 *  \param name the new name
 */

/*! \fn const QColor& MC_3DShapeModel :: colour()const;
    \brief Returns the colour
    \return
 */

/*! \fn void MC_3DShapeModel :: setColour(const QColor& colour);
 *  \brief Sets the colour of the shape
 *  \param colour the new colour
 */

/*! \fn const QVector3D& MC_3DShapeModel :: minPoint()const
    \brief Gets the minimal point
    \return
 */

/*! \fn const QVector3D& MC_3DShapeModel :: maxPoint()const
    \brief Gets the maximal point
    \return
 */

/*! \fn const MC_3DShape* MC_3DShapeModel :: get3DShape()const
    \brief Gets the shape
    \return a pointer to the shape
 */

#endif
