/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "ECGViewerWidget.h"

#include <QFileDialog>
#include <QDir>
#include <QProgressDialog>

#include <QPaintEvent>
#include <QResizeEvent>

#include <QDebug>

#include "Parser/ecg/ECGFileParser.h"

#include "Logger/Logger.h"

ECGViewerWidget :: ECGViewerWidget(Logger* pLogger, QWidget* parent)
    :QWidget(parent),m_renderer(&m_ecgList,this->size()),m_pLogger(pLogger)
{
    m_parsersFactory.registerParser("ecg",new ECGFileParser());
}

ECGViewerWidget :: ~ECGViewerWidget()
{

}

void ECGViewerWidget :: clearData()
{
    m_ecgList.clear();
}

void ECGViewerWidget :: loadECGFile(const QString& name, const QByteArray& file)
{
    bool bResult = m_parsersFactory.parse(file,"ecg",m_ecgList,name);
    if ( bResult == false )
    {
        m_pLogger->warning("Fail to load '" + name + "'");
    }
}

void ECGViewerWidget :: loadECGFiles()
{
    // Construct the list of extension for the filters
    QString filters = tr("ECG Files (");
    QStringList availableExtensions = m_parsersFactory.getAvailableExtensions();
    foreach(QString extension, availableExtensions)
    {
        filters.append(" *." + extension);
    }
    filters.append(")");

    QStringList fileNames = QFileDialog::getOpenFileNames(this,tr("Open ECG files"),QDir::currentPath(),filters);
    if ( !fileNames.isEmpty() )
    {
        QProgressDialog progressBar(tr("Loading radio files..."),QString(),0,fileNames.count(),this);
        foreach (QString fileName, fileNames)
        {
            if ( !m_ecgList.contains(fileName) )
            {
                bool bResult = m_parsersFactory.parse(fileName,m_ecgList);
                if ( bResult == false )
                {
                    m_pLogger->warning("Fail to load '" + fileName + "'");
                }
            }

            progressBar.setValue(progressBar.value()+1);
        }
    }

    m_renderer.generatePaths();
    this->repaint();
}

void ECGViewerWidget :: paintEvent(QPaintEvent* pPaintEvent)
{
    QPainter painter(this);
    m_renderer.paint(&painter);
    pPaintEvent->accept();
}

void ECGViewerWidget :: resizeEvent(QResizeEvent* pResizeEvent)
{
    m_renderer.setSurfaceSize(pResizeEvent->size());
}
