#ifndef __ECGFILEPARSER_H__
#define __ECGFILEPARSER_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "Parser/ECGParser.h"

#include <QMap>
#include <QString>
#include <QColor>

class QByteArray;

class ECGList;

class ECGFileParser : public ECGParser
{

protected:

    bool parseData(const QByteArray& data, ECGList& ecgList, const QString& ecgName);

public:

    ECGFileParser() {}
    ~ECGFileParser() {}
};

/*! \class ECGFileParser ECGFileParser.h "Parser/ecg/ECGFileParser.h"
    \brief ECGParser implementation to read the .ecg files

    .ecg files are composed as following:
        - point1
        - point2
        - .
        - .
        - .
        - pointN
 */

/*! \fn ECGFileParser :: ECGFileParser()
 */

/*! \fn ECGFileParser :: ~ECGFileParser()
 */

/*! \fn bool ECGFileParser :: parseData(const QByteArray& data, ECGList& ecgList, const QString& ecgName)
 *  \brief Parse data to construct a new ECG stored in ecgList
 *  \param data the data to parse
 *  \param ecgList the list of ECGs where to add the new ECG
 *  \param ecgName the name of the new ECG
 *  \return true if all goes right
 */

#endif
