#ifndef __ECG_H__
#define __ECG_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QString>
#include <QList>
#include <QColor>

class ECG
{
private:
    QString m_name;         /*!< */
    QList<float> m_data;    /*!< */

    QColor m_color;         /*!< */

    float m_min;            /*!< */
    float m_max;            /*!< */

public:
    ECG();

    void appendData(float newData);

    const QString& name()const { return m_name; }
    void setName(const QString& name) { m_name = name; }
    const QList<float>& data()const { return m_data; }

    const QColor& color()const { return m_color; }
    void setColor(const QColor& color) { m_color = color; }

    float min()const { return m_min; }
    float max()const { return m_max; }
};

/*! \class ECG ECG.h "Types/ECG.h"
    \brief ECG data type
 */

/*! \fn ECG :: ECG()
 */

/*! \fn void ECG :: appendData(float newData)
    \brief add a new data to the ECG
    \param newData
  */

/*! \fn const QString& ECG :: name()const
    \return the name of the ECG
  */

/*! \fn void ECG :: setName(const QString& name)
    \brief Define the name of the ECG
    \param name
 */

/*! \fn const QList<float>& ECG :: data()const
    \brief Get the ECG data
    \return
 */

/*! \fn const QColor& ECG :: color()const
    \brief Gets the color of the ECG
    \return
 */

/*! \fn void ECG :: setColor(const QColor& color)
    \brief Define the color of the ECG
    \param color the new color
*/

/*! \fn float ECG :: min()const
    \brief Get the min point of the ECG
    \return
*/

/*! \fn float ECG :: max()const
    \brief Get the max point of the ECG
    \return
*/

#endif
