#ifndef __ECGLIST_H__
#define __ECGLIST_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QList>

#include "ECG.h"

class ECGList
{
private:
    QList<ECG> m_ecgs;  /*!< */

    float m_min;        /*!< */
    float m_max;        /*!< */

public:
    ECGList():m_min(100000),m_max(-1000000) {}
    ~ECGList() {}

    void add(const ECG& ecg);

    bool contains(const QString& name)const;
    void clear();

    const QList<ECG>& getList()const { return m_ecgs; }

    float min()const { return m_min; }
    float max()const { return m_max; }
};

/*! \class ECGList ECGList.h "Types/ECGList.h"
    \brief List of ECGs
 */

/*! \fn ECGList :: ECGList()
 */

/*! \fn ECGList :: ~ECGList()
 */

/*! \fn void ECGList :: add(const ECG& ecg)
    \brief add an ECG in the list
    \param ecg the new ECG
 */

/*! \fn bool ECGList :: contains(const QString& name)const
    \brief Check if name is known in the list
    \param name the name to search
    \return true if the name is found in the list
 */

/*! \fn void ECGList :: clear()
    \brief Clear the list
    Reinitialise the min/max point
  */

/*! \fn const QList<ECG>& ECGList :: getList()const
    \brief Gets the list
    \return
 */

/*! \fn float ECGList :: min()const
    \brief Get the min point of the list
    \return
*/

/*! \fn float ECGList :: max()const
    \brief Get the max point of the list
    \return
*/

#endif
