/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "FileLogger.h"

#include <QDebug>

FileLogger :: FileLogger(const QString& fileName)
    :m_logFile(fileName)
{
    m_logFile.open(QIODevice::WriteOnly | QIODevice::Text);
    if (m_logFile.isOpen() == false)
    {
        qDebug() << "Fail to open log file '" << fileName << "'";
    }
}

FileLogger :: ~FileLogger()
{
    this->debug("Log stopped");
    this->dump();
    m_logFile.close();
}

void FileLogger :: dump()
{
    QTextStream stream(&m_logFile);
    foreach(LogMessage logMessage, m_messages)
    {
        stream << logMessage.m_logTime.toString() << ":\t";
        switch (logMessage.m_logLevel )
        {
        case LL_Debug:
            stream << "DEBUG\t";
            break;
        case LL_Warning:
            stream << "WARNING\t";
            break;
        case LL_Error:
            stream << "ERROR\t";
            break;
        }

        stream << logMessage.m_message << "\n";
    }

    m_messages.clear();
}
