#ifndef __LOGGER_H__
#define __LOGGER_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "Logger_global.h"

#include <QDateTime>

class LOGGERSHARED_EXPORT Logger
{

protected:
    enum LogLevel
    {
        LL_Debug,
        LL_Warning,
        LL_Error
    };

    struct LogMessage
    {
        LogLevel m_logLevel;    /*!< */
        QDateTime m_logTime;    /*!< */
        QString m_message;      /*!< */

        LogMessage(LogLevel logLevel, const QDateTime& logTime, const QString& message)
            :m_logLevel(logLevel),m_logTime(logTime),m_message(message) {}
    };

private:

    static const int BUFFER_SIZE = 2048;

    void log(LogLevel logLevel, const QString& message);

protected:
    QList<LogMessage> m_messages;   /*!< messages logged */

public:
    Logger();
    virtual ~Logger() {}

    void debug(const QString& message);
    void warning(const QString& message);
    void error(const QString& message);

    virtual void dump()=0;
};

/*! \class Logger Logger.h "Logger.h"
 *  \brief Keep application messages with relevancy levels
 *  The logger keep a list of message with the date and the level.
 *  When too much messages are in the instance, the logger will dump these messages and clear the previous entries
 */

 /*! \enum Logger::LogLevel
 *  Level of importance of the message
 */

/*! \struct Logger::LogMessage Logger.h "Logger.h"
 *  \brief Internal structure to keep the message with their date and level
 */

/*! \fn Logger::LogMessage :: LogMessage(LogLevel logLevel, const QDateTime& logTime, const QString& message)
 *  \param logLevel the level of the message
 *  \param logTime the time when the message has been received
 *  \param message the message itself
 */

/*! \fn Logger :: Logger()
 */

/*! \fn virtual Logger :: ~Logger()
 */

/*! \fn void Logger :: debug(const QString& message)
 *  \brief Log a debug message (low importancy)
 *  \param message
 */

/*! \fn void Logger :: warning(const QString& message)
 *  \brief Log a warning message (message importancy)
 *  \param message
 */

 /*! \fn void Logger :: error(const QString& message)
 *  \brief Log a error message (high importancy)
 *  \param message
 */

/*! \fn virtual void Logger :: dump()=0
 *  \brief dump the messages
 */

#endif
