import QtQuick 1.0

Item
{
    width: 500
    height: 500

    signal userNew(string name, string password, string category)

    signal userNameChanged(string oldName, string newName)
    signal userCategoryChanged(string name, string newCategory)
    signal userRemoved(string name);

    ListView
    {
        id: userList
        height: 500-40
        width: 500
        spacing: 1

        model: userNames
        delegate:
            UserEdit
            {
                id: delegateObject
                width: 500
                uName: name
                uCategory: category

                Item
                {
                    id: keeper;
                    property string keep: name;
                }

                onNameChanged: { userNameChanged(keeper.keep,newName) ; keeper.keep = newName }
                onCategoryChanged: { userCategoryChanged(delegateObject.uName,newCategory) }
                onRemoved: { userRemoved(name) }
            }
    }

    Rectangle
    {
        id: addUserBox

        width: parent.width
        height: 100

        anchors.top:  userList.bottom

        TextInformationEdit
        {
            id: nameEdit
            width: 200

            labelText: "Name: "
            text: ""

            onInformationChanged: { text = newInfo }
        }

        TextInformationEdit
        {
            id: passwordEdit
            width: 200

            anchors.right: parent.right
            anchors.rightMargin: 5

            labelText: "Password: "
            text: ""

            onInformationChanged: { text = newInfo }
        }

        TextInformationEdit
        {
            id: categoryEdit

            anchors.top: passwordEdit.bottom
            anchors.topMargin: 5

            labelText: "Category: "
            text: ""
            validator: IntValidator{ bottom: 0; top: 99999}
            informationXOffset: 5

            onInformationChanged: { text = newInfo }
        }

        Button
        {
            width: parent.width
            height: 16

            anchors.top: categoryEdit.bottom

            title: "Add new"

            onButtonClick: { userNew(nameEdit.text, passwordEdit.text, categoryEdit.text);
                nameEdit.text = "";
                passwordEdit.text = "";
                categoryEdit.text = "" }
        }
    }
}
