/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "NClient.h"

#include <QHostAddress>
#include <QDebug>

#include <cassert>

#include "Network/Utils/DataUtils.h"
#include "Logger/Logger.h"

NClient :: NClient(Logger* pLogger, const QString& virtualMachineName, QObject* parent)
    :QObject(parent),m_pLogger(pLogger),m_peerAddress("-1.-1.-1.-1"),m_virtualMachineName(virtualMachineName)
{
    assert(pLogger);
}

NClient :: ~NClient()
{
    m_pSocket->disconnectFromHost();
    m_pSocket->deleteLater();
}

void NClient :: reportError(QAbstractSocket::SocketError errorId)
{
    m_pLogger->warning(QString("Client '" + m_virtualMachineName + "' socket error %1").arg(errorId) + " -> " + m_pSocket->errorString());
    emit errorOccured(this);
}

void NClient :: connected()
{
    m_peerAddress = m_pSocket->peerAddress().toString();
    m_pLogger->debug("Client '" + m_virtualMachineName + "' connected to " + m_peerAddress);
    emit connected(this);
}

void NClient :: write(const QByteArray& data)
{
    if ( m_pSocket->isValid() == false )
    {
        qDebug() << "Trying to write on invalide socket";
    }
    char lengthData[4];
    DataUtils::intToDWordChar(data.size(),lengthData);
    m_pSocket->write(lengthData,4);
    quint64 bytesWritten = m_pSocket->write(data);
    qDebug() << bytesWritten << "bytes written";

}
