#ifndef __NCLIENT_H__
#define __NCLIENT_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QObject>
#include <QAbstractSocket>

class Logger;

class NClient : public QObject
{
    Q_OBJECT

protected:
    Logger* m_pLogger;              /*!< */

    QAbstractSocket* m_pSocket;     /*!< */
    QString m_peerAddress;          /*!< Address of the distant machine */
    QString m_virtualMachineName;   /*!< Name of the distant machine (given by the config file from the NetworkManager) */

    Q_SLOT void reportError(QAbstractSocket::SocketError errorId);
    Q_SLOT void connected();

public:
    NClient(Logger* pLogger, const QString& virtualMachineName, QObject* parent=0);
    virtual ~NClient();

    virtual void connectSocket(const QString& hostName, quint16 port)=0;
    void write(const QByteArray& data);

    const QString& peerAddress() { return m_peerAddress; }
    const QString& virtualMachineName() { return m_virtualMachineName; }

    Q_SIGNAL void errorOccured(NClient* pClient);
    Q_SIGNAL void connected(NClient* pClient);
};

/*! \class NClient "NClient.h" "Network/Client/NClient.h"
    \brief Base class for client on network
 */

/*! \fn void NClient :: reportError(QAbstractSocket::SocketError errorId)
    \brief Report socket errors
    \param errorId
 */

/*! \fn void NClient :: connected()
    \brief Complete information at socket connection
 */

/*! \fn NClient :: NClient(Logger* pLogger, const QString& virtualMachineName, QObject* parent=0)
    \param pLogger
    \param virtualMachineName the name of the machine for the server initiating the connection
    \param parent
 */

/*! \fn virtual NClient::~NClient()
 */

/*! \fn virtual void NClient::connectSocket(const QString& hostName, quint16 port)=0
    \brief connect the socket to <a>hostName</a> using <a>port</a>
    \param hostName the machine to connect
    \param port the port where to connect
 */

/*! \fn void NClient :: write(const QByteArray& data)
    \brief Writes <a>data</a> on the network
    \param data
 */

/*! \fn const QString& NClient::peerAddress()
    \brief Returns the address of the distant machine
    \return
 */

/*! \fn const QString& NClient::virtualMachineName()
    \brief Returns the name of the machine linked to this socket
    \return
 */

/*! \fn void NClient::errorOccured(NClient* pClient)
    \brief Signal sent when an error occured
    \param pClient pointer to the client causing the error
 */

/*! \fn void NClient::connected(NClient* pClient)
    \brief Signal sent when the client is connected
    \param pClient pointer to the client newly connected
 */

#endif
