/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "SSLClient.h"

#include <QObject>
#include <QString>
#include <QSslSocket>
#include <QSslKey>
#include <QFile>
#include <QDebug>

#include "Network/SSLException.h"

#include "Logger/Logger.h"

SSLClient :: SSLClient(Logger* pLogger, const QString& virtualMachineName, QObject* parent)
    :NClient(pLogger,virtualMachineName,parent)
{
    QSslSocket* pSocket = new QSslSocket(parent);

    QFile file( "./data/SSL_Cert/client-key.pem" );
    if( ! file.open( QIODevice::ReadOnly ) )
    {
        m_pLogger->warning("File './data/SSL_Cert/client-key.pem' not found");
        throw SSLException();
    }

    QSslKey key( &file, QSsl::Rsa, QSsl::Pem, QSsl::PrivateKey, "MedCenterSSL" );
    file.close();

    pSocket->setPrivateKey( key );

    pSocket->setLocalCertificate( "./data/SSL_Cert/client-crt.pem" );

    if( ! pSocket->addCaCertificates( "./data/SSL_Cert/ca.pem" ) )
    {
         m_pLogger->warning("File './data/SSL_Cert/ca.pem' not found");
         return;
    }

    pSocket->setPeerVerifyMode(QSslSocket::VerifyNone);

    pSocket->ignoreSslErrors();

    connect(pSocket,SIGNAL(error(QAbstractSocket::SocketError)),this, SLOT(reportErrors(QAbstractSocket::SocketError)));
    connect(pSocket,SIGNAL(sslErrors(QList<QSslError>)),this, SLOT(reportErrors(QList<QSslError>)));
    m_pSocket = pSocket;
}

void SSLClient :: reportErrors(QList<QSslError> sslErrors)
{
    foreach(QSslError sslError, sslErrors)
    {
        qDebug() << "SSLErrors: " << sslError.errorString();
    }
}

void SSLClient :: connectSocket(const QString& hostName, quint16 port)
{
    QSslSocket* pSocket = qobject_cast<QSslSocket*>(m_pSocket);
    pSocket->connectToHostEncrypted(hostName,port,QIODevice::WriteOnly);

    pSocket->startClientEncryption();

    qDebug() << "SSLClient::connectSocket(" << hostName << ";" << port << ")";
}
