/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "PatientContainer.h"

#include "Types/Patient.h"
#include "Types/PatientData.h"
#include "Types/VersionData.h"

#include <QFile>
#include <QDebug>

PatientContainer :: ~PatientContainer()
{
    foreach(Patient* pPatient, m_patients.values())
    {
        delete pPatient;
    }

    m_patients.clear();
}

bool PatientContainer :: add(Patient* pPatient)
{
    PatientData* pPatientData = dynamic_cast<PatientData*>(pPatient->get("PatientData"));

    if ( pPatientData )
    {
        if ( m_patients.contains(pPatientData->name()) ) // Protection when over writting Patient
        {
            if ( m_patients[pPatientData->name()] == pPatient ) // Same pointer ... do nothing
            {
                return true;
            }

            VersionData* pNewVersionData = dynamic_cast<VersionData*>(pPatient->get("VersionData"));
            VersionData* pOldVersionData = dynamic_cast<VersionData*>(m_patients[pPatientData->name()]->get("VersionData"));
            if ( !(pNewVersionData && pOldVersionData) )
            {
                qWarning() << "No version data found!";
                return false;
            }

            if ( pNewVersionData->version() > pOldVersionData->version() )  // New version available ; do update
            {
                delete m_patients[pPatientData->name()];    // Delete previous version of patient
                m_patients[pPatientData->name()] = pPatient;
                return true;
            }
            else
            {
                return false;
            }
        }
        else // Simple add the totally new patient
        {
            m_patients[pPatientData->name()] = pPatient;
            return true;
        }


    }
    else
    {
        qWarning() << "The patient given to the PatientContainer does not have PatientData field (-> not added)";
        return false;
    }
}

Patient* PatientContainer :: get(const QString& name)
{
    if ( m_patients.contains(name))
    {
        return m_patients[name];
    }
    // else
    return NULL;
}

QList<QString> PatientContainer :: getPatientNameList()
{
    return m_patients.keys();
}

QList<Patient*> PatientContainer :: getPatientsList()
{
    return m_patients.values();
}

void PatientContainer::load(const QString& fileName)
{
    QFile dataFile(fileName);
    if ( dataFile.open(QIODevice::ReadOnly))
    {
        Patient* pPatient = new Patient();
        pPatient->load(dataFile.readAll());
        this->add(pPatient);
    }
    dataFile.close();
}

bool PatientContainer::save(const QString& fileName)
{
    QFile saveFile(fileName);
    if ( saveFile.open(QIODevice::WriteOnly))
    {
        foreach(Patient* pPatient, m_patients)
        {
            saveFile.write(pPatient->data());
        }
    }
    else
    {
        return false;
    }

    saveFile.close();

    return true;
}
