#ifndef __PATIENTCONTAINER_H__
#define __PATIENTCONTAINER_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QMap>
#include <QString>

class Patient;

class PatientContainer
{
private:
    QMap<QString, Patient*> m_patients; /*!< */

public:

    ~PatientContainer();

    bool add(Patient* pPatient);
    Patient* get(const QString& name);
    QList<QString> getPatientNameList();
    QList<Patient*> getPatientsList();

    void load(const QString& fileName);
    bool save(const QString& fileName);
};

/*! \class PatientContainer PatientContainer.h "PatientContainer.h"
    \brief Container for Patient data
 */

/*! \fn PatientContainer :: ~PatientContainer()
    \brief Delete the patient data saved in the container
 */

/*! \fn void PatientContainer :: add(Patient* pPatient)
    \brief Adds a new patient
    \param pPatient pointer to the new patient
 */

/*! \fn Patient* PatientContainer :: get(const QString& name)
    \brief Gets a patient based on his <a>name</a>
    \param name the name of the patient to get
    \return the pointer to the patient
 */

/*! \fn QList<QString> PatientContainer :: getPatientNameList()
    \brief Gets the list of patient's names
    \return
 */

/*! \fn QList<Patient*> PatientContainer :: getPatientsList()
    \brief Gets the list of patient's data
    \return
 */

/*! \fn void PatientContainer :: load(const QString& fileName)
    \brief Loads patients from a file
    \param fileName name of the file where to read
 */

/*! \fn bool PatientContainer :: save(const QString& fileName)
    \brief Save patients in a file
    \param fileName name of the file where to write
 */

#endif
