#ifndef __CHANGEMENT_H__
#define __CHANGEMENT_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QObject>
#include <QString>
#include <QDateTime>

class Changement : public QObject
{
    Q_OBJECT

    Q_PROPERTY(QString userName READ userName CONSTANT)
    Q_PROPERTY(QString time READ timeString CONSTANT)
    Q_PROPERTY(QString message READ message CONSTANT)

private:
    QString m_userName; /*!< */
    QDateTime m_time;   /*!< */
    QString m_message;  /*!< */

public:
    Changement(QObject* parent=0):QObject(parent) {}
    Changement(const QString& userName, const QDateTime& time, const QString& message, QObject* parent=0)
        :QObject(parent),m_userName(userName),m_time(time),m_message(message) {}
    Changement(const Changement& changement)
        :QObject(changement.parent()),m_userName(changement.userName()),m_time(changement.time()),m_message(changement.message()) {}

    Changement& operator=(const Changement& changement);

    ~Changement() {}

    const QString& userName()const { return m_userName; }
    const QDateTime& time()const { return m_time; }
    QString timeString()const { return m_time.toString(); }
    const QString& message()const { return m_message; }
};

/*! \class Changement Changement.h "Types/Changement.h"
    \brief Handle changes information
*/

/*! \fn Changement::Changement(QObject* parent=0)
    \param parent
 */

/*! \fn Changement::Changement(const QString& userName, const QDateTime& time, const QString& message, QObject* parent=0)
    \param userName
    \param time
    \param message
    \param parent
 */

/*! \fn Changement::Changement(const Changement& changement)
    \param changement
 */

/*! \fn Changement& Changement::operator=(const Changement& changement)
    \param changement
    \return
 */

/*! \fn Changement::~Changement()
 */

/*! \fn const QString& Changement::userName()const
    \brief the name of the creator of the change
    \return
 */

/*! \fn const QDateTime& Changement::time()const
    \brief returns the time of the changement
    \return
 */

/*! \fn QString Changement::timeString()const
    \brief return time in string formatting (for QML)
    \return
 */

/*! \fn const QString& Changement::message()const
    \brief returns the information message
    \return
 */

#endif
