/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "Data.h"

#include <QDebug>
#include <cassert>

#include "Patient.h"
#include "ListData.h"
#include "VersionData.h"
#include "PatientData.h"
#include "OperationData.h"
#include "FileData.h"

#include "Utils/ByteArrayUtils.h"

void Data :: factory(Patient* pPatient, const QByteArray& data, int index, int* nbRead)
{
    int localNbRead = 0;
    int nbReadType = 0;
    QString dataName;
    Data* pData;

    assert(pPatient);

    int dataType = ByteArrayUtils::readNumber(data,index,&nbReadType);
    switch ( dataType )
    {
    case SDI_Version:
        pData = new VersionData();
        break;
    case SDI_Patient:
        pData = new PatientData();
        break;
    case SDI_Operation:
        pData = new OperationData();
        break;
    case SDI_File:
        pData = new FileData();
        break;
    default:
        qDebug() << "Data not recognised";
        if ( nbRead )
        {
            *nbRead = -1;
        }
        return;
    }

    localNbRead = pData->load(data,index+nbReadType);
    if ( localNbRead != -1 )
    {
        switch ( dataType )
        {
        case SDI_Version:
        case SDI_Patient:
            pPatient->add(pData->category(),pData);
            break;
        case SDI_Operation:
            {
                ListData<OperationData>* pOperationList = NULL;
                if ( pPatient->exist("Operations") )
                {
                    pOperationList = dynamic_cast<ListData<OperationData>*>(pPatient->get("Operations"));
                }
                else
                {
                    pOperationList = new ListData<OperationData>();
                    pPatient->add("Operations",pOperationList);
                }

                pOperationList->add(dynamic_cast<OperationData*>(pData));
            }
            break;
        case SDI_File:
            {
                ListData<FileData>* pFileList = NULL;
                if ( pPatient->exist(pData->category()) )
                {
                    pFileList = dynamic_cast<ListData<FileData>*>(pPatient->get(pData->category()));
                }
                else
                {
                    pFileList = new ListData<FileData>();
                    pPatient->add(pData->category(),pFileList);
                }

                pFileList->add(dynamic_cast<FileData*>(pData));
            }
            break;
        }
    }

    if ( nbRead )
    {
        *nbRead = localNbRead + nbReadType;
    }
}
