#ifndef __FILEDATA_H__
#define __FILEDATA_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "Data.h"

#include <QString>
#include <QByteArray>

class FileData : public Data
{
    enum FileDataIdentifier
    {
        FDI_CATEGORY = 301,
        FDI_NAME = 302,
        FDI_FOLDER = 303,
        FDI_DATA = 304
    };

private:
    QString m_name;
    QString m_folder;
    QByteArray m_data;

public:
    FileData():Data("") {}
    FileData(const QString& category, const QString& name, const QString& folder, const QByteArray& data)
        :Data(category),m_name(name),m_folder(folder),m_data(data) {}
    ~FileData() {}

    QByteArray data()const;
    int load(const QByteArray& data, int index=0);

    const QString& name()const { return m_name; }
    const QString& folder()const { return m_folder; }
    const QByteArray& fileData()const { return m_data; }

    void setFolder(const QString& folder) { m_folder = folder; }
};

/*! \class FileData FileData.h "Types/FileData.h"
    \brief Implementation to send file over the network
 */

/*! \enum FileData::FileDataIdentifier
    \brief Identifiers for FileData segment
 */

/*! \fn FileData::FileData()
 */

/*! \fn FileData::FileData(const QString& category, const QString& name, const QString& folder, const QByteArray& data)
    \param category
    \param name
    \param folder
    \param data
 */

/*! \fn FileData::~FileData()
 */

/*! \fn const QString& FileData::name()const
    \return name of the file
 */

/*! \fn const QString& FileData::folder()const
    \return folder of the file
 */

/*! \fn const QByteArray& FileData::fileData()const
    \return the file
 */

/*! \fn void FileData::setFolder(const QString& folder)
    \brief Sets a new folder for this file
    \param folder
 */

#endif
