#ifndef __OPERATIONDATA_H__
#define __OPERATIONDATA_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "Data.h"

#include <QString>
#include <QDate>

#include "Types/ListData.h"

class OperationData : public Data
{
    Q_OBJECT

    Q_PROPERTY(QString name READ name CONSTANT)
    Q_PROPERTY(QDate date READ date CONSTANT)
    Q_PROPERTY(QString observation READ observation CONSTANT)

    enum OperationDataIdentifier
    {
        ODI_NAME = 201,
        ODI_DATE,
        ODI_OBSERVATION
    };

private:
    int m_id;               /*!< */
    QString m_name;         /*!< */
    QDate m_date;           /*!< */
    QString m_observation;  /*!< */

public:
    OperationData(QObject* parent=0):Data("Operation",parent) {}
    OperationData(const int id, const QString& name, const QDate& date, const QString& observation, QObject* parent=0)
        :Data("Operation",parent),m_id(id),m_name(name),m_date(date),m_observation(observation) {}

    int load(const QByteArray &data, int index=0);
    QByteArray data()const;

    const QString& name()const { return m_name; }
    const QDate& date()const { return m_date; }
    const QString& observation()const { return m_observation; }
    int id()const { return m_id; }

    void setName(const QString& newName) { m_name = newName; }
    void setDate(const QDate& newDate) { m_date = newDate; }
    void setObservation(const QString& newObservation) { m_observation = newObservation; }

    static OperationData* searchName(const QList<OperationData*>& list, const QString& name);
};

/*! \class OperationData OperationData.h "Types/OperationData.h"
    \brief Information about operations
 */

/*! \enum OperationData::OperationDataIdentifier
    \brief Identifiers for OperationData segment
 */

/*! \fn OperationData::OperationData(QObject* parent=0)
    \param parent
*/

/*! \fn OperationData::OperationData(const int id, const QString& name, const QDate& date, const QString& observation, QObject* parent=0)
    \brief
    \param id
    \param name
    \param date
    \param observation
    \param parent
 */

/*! \fn const QString& OperationData::name()const
    \brief returns the name
    \return the name
 */

/*! \fn const QDate& OperationData::date()const
    \brief returns the age
    \return the date
 */

/*! \fn const QString& OperationData::observation()const
    \brief returns the observation
    \return the observation
 */

/*! \fn int OperationData::id()const
    \brief Get the id of the operation
    \return
 */

/*! \fn void OperationData::setName(const QString& newName)
    \brief Sets a new name
    \param newName
 */

/*! \fn void OperationData::setDate(const QDate& newDate)
    \brief Sets a new date
    \param newDate
 */

/*! \fn void OperationData::setObservation(const QString& newObservation)
    \brief Sets a new observation
    \param newObservation
 */

/*! \fn static OperationData* OperationData::searchName(const QList<OperationData*>& list, const QString& name);
    \brief Search an operation of name
    \param list the list of operation where to search
    \param name the name to search
    \return a pointer on the operation if found ; or NULL
 */

#endif
