#include "Patient.h"

#include <QStringList>
#include <QDebug>

Patient :: ~Patient()
{
    foreach(Data* pData, m_data.values())
    {
        delete pData;
    }
}

QByteArray Patient :: data()const
{
    QByteArray dataArray;
    foreach(Data* pData, m_data.values())
    {
        dataArray.append(pData->data());
    }

    return dataArray;
}

bool Patient :: load(const QByteArray& data, int baseIndex)
{
    int index = baseIndex;
    bool canReadData = true;

    while ( canReadData && index < data.size() )
    {
        int nbRead = 0;
        Data::factory(this,data,index,&nbRead);
        if ( nbRead == -1 )
        {
            qDebug() << "Problem to read data for Patient";
            return false;
        }

        index+=nbRead;
    }

    m_isValid = true;
    return true;
}

void Patient :: add(const QString& name, Data* pData)
{
    if ( m_data.contains(name) )
    {
        qWarning() << "Overwriting some Data '" << name << "' for Patient";
    }

    m_data[name] = pData;
}

bool Patient :: exist(const QString& name)const
{
    return m_data.contains(name);
}

Data* Patient :: get(const QString& name)const
{
    if ( this->exist(name) )
    {
        return m_data[name];
    }
    qDebug() << "Patient::get(" << name << ") does not exist";
    // else
    return NULL;
}

QStringList Patient :: getFileFolderList()const
{
    QStringList fileNames;
    foreach(QString name, m_data.keys())
    {
        if ( name != "PatientData" &&
             name != "Operations" &&
             name != "VersionData" )
        {
            fileNames << name;
        }
    }

    return fileNames;
}
