#ifndef __PATIENT_H__
#define __PATIENT_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QMap>
#include <QString>

#include "Data.h"

class Patient
{
private:
    QMap<QString, Data*> m_data;
    int m_id;

    bool m_isValid;

public:
    Patient():m_isValid(false) {}
    ~Patient();

    QByteArray data()const;
    bool load(const QByteArray& data, int baseIndex=0);

    void add(const QString& name, Data* pData);
    bool exist(const QString& name)const;
    Data* get(const QString& name)const;
    QStringList getFileFolderList()const;

    int id()const { return m_id; }

    bool isValid()const { return m_isValid; }
};

class SimplePatient
{
private:
    QString m_name;     /*!< */
    int m_id;           /*!< */

public:
    SimplePatient(const QString& name, int id):m_name(name),m_id(id) {}

    const QString& name() { return m_name; }
    int id() { return m_id; }
};

/*! \class Patient Patient.h "Types/Patient.h"
    \brief The Patient class is a container of all the Patient information.
    The informations are kept in a map and recognised by their category
 */

/*! \fn Patient::Patient()
    \brief Creates an invalid patient
 */

/*! \fn Patient::~Patient()
 */

/*! \fn virtual QByteArray Patient::data()const =0
    \brief Gets the Patient data in the form of a QByteArray (ready to be shared on the network)
    \return
 */

/*! \fn bool Patient::load(const QByteArray& data, int baseIndex=0)
    \brief load Patient from a QByteArray
    \param data the data to load
    \param baseIndex the index where to start to read
    \return true if all goes right
 */

/*! \fn void Patient::add(const QString& name, Data* pData)
    \brief Add some Data in this patient under the category 'name'
    \param name the name identifying these data
    \param pData a pointer to the Data
 */

/*! \fn bool Patient::exist(const QString& name)const
    \brief Checks if the identifier <a>name</a> exist in the Patient set
    \param name
    \return true if it exists (and can be get)
 */

/*! \fn Data* Patient::get(const QString& name)const
    \brief Gets the Data identified by <a>name</a>
    \param name
    \return a pointer to the Data (don't desallocate this pointer)
 */

/*! \fn QStringList Patient::getFileFolderList()const
    \brief Get the list of file folders
    \return
 */

/*! \fn int Patient::id()const
    \brief Gets the id
    \return
 */

/*! \fn bool Patient::isValid()const
    \brief Gets if the user is valid
    \return true if the user is valid
 */


/*! \class SimplePatient Patient.h "Types/Patient.h"
    \brief The SimplePatient is a class giving only the name and the associated id for a patient
 */

/*! \fn SimplePatient::SimplePatient(const QString& name, int id)
    \brief
    \param name
    \param id
*/

/*! \fn const QString& SimplePatient::name()
    \brief
    \return
 */

/*! \fn int SimplePatient::id()
    \brief
    \return
 */

#endif
