#ifndef __PATIENTDATA_H__
#define __PATIENTDATA_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "Data.h"

#include <QString>
#include <QObject>

class PatientData : public Data
{
    Q_OBJECT

    Q_PROPERTY(QString name READ name CONSTANT)
    Q_PROPERTY(int age READ age CONSTANT)
    Q_PROPERTY(int room READ room CONSTANT)

    enum PatientDataIdentifier
    {
        PDI_NAME = 101,
        PDI_AGE,
        PDI_ROOM
    };

private:
    QString m_name;     /*!< */
    short int m_age;    /*!< */
    int m_room;         /*!< */

public:
    PatientData(QObject* parent=0):Data("PatientData",parent),m_age(-1) {}
    PatientData(const QString& name, short int age, QObject* parent=0):Data("PatientData",parent),m_name(name),m_age(age) {}

    QByteArray data()const;
    int load(const QByteArray& data, int index=0);

    const QString& name()const { return m_name; }
    short int age()const { return m_age; }
    int room()const { return m_room; }

    void setName(const QString& newName) { m_name = newName; }
    void setAge(const short int newAge) { m_age = newAge; }
};

/*! \class PatientData PatientData.h "Types/PatientData.h"
    \brief Information about the patient itself (such as his name / age, ...)
 */

/*! \enum PatientData::PatientDataIdentifier
    \brief Identifiers for the PatientData segment
 */

/*! \fn PatientData::PatientData(QObject* parent=0)
    \param parent
 */

/*! \fn PatientData::PatientData(const QString& name, short int age, QObject* parent=0)
    \param name
    \param age
    \param parent
 */

/*! \fn const QString& PatientData::name()const
    \brief returns the name of the Patient
    \return the name
 */

/*! \fn short int PatientData::age()const
    \brief Gets the age
    \return the age
 */

/*! \fn short int PatientData::room()const
    \brief Gets the room
    \return the room
 */

/*! \fn void PatientData::setName(const QString& newName)
    \brief Change the patient name
    \param newName
 */

/*! \fn void PatientData::setAge(const short int newAge)
    \brief Change the patient age
    \param newAge
 */

#endif
