/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "VersionData.h"

#include "Utils/ByteArrayUtils.h"

#include <QDebug>

void VersionData :: addChangement(const Changement& change)
{
    m_changements.append(change);
    m_version++;
}

QByteArray VersionData :: data() const
{
    QByteArray dataArray;

    ByteArrayUtils::writeNumber<int>(dataArray,SDI_Version);
    ByteArrayUtils::writeNumber<int>(dataArray,VDI_VERSION);
    ByteArrayUtils::writeNumber<int>(dataArray,m_version);

    foreach(Changement change, m_changements)
    {
        ByteArrayUtils::writeNumber<int>(dataArray,VDI_CHANGEMENT);
        ByteArrayUtils::writeString(dataArray,change.userName());
        ByteArrayUtils::writeDateTime(dataArray,change.time());
        ByteArrayUtils::writeString(dataArray,change.message());
    }

    return dataArray;
}

int VersionData :: load(const QByteArray &data, int index)
{
    int localIndex = index;
    bool canReadData = true;

    while ( canReadData && localIndex < data.size()  )
    {
        int nbReadType = 0;
        int dataType = ByteArrayUtils::readNumber(data,localIndex,&nbReadType);
        if (nbReadType == -1)
        {
            qDebug() << "Fail to read the type of data for PatienData";
            return -1;
        }

        localIndex+=nbReadType;

        switch (dataType)
        {
        case VDI_VERSION:
            {
                int byteRead = 0;
                m_version = ByteArrayUtils::readNumber(data,localIndex,&byteRead);
                if ( byteRead == -1 )
                {
                    qDebug() << "VersionData: failed to read version number";
                    canReadData = false;
                }

                localIndex += byteRead;
            }
            break;
        case VDI_CHANGEMENT:
            {
                Changement change;
                int byteRead = 0;
                QString userName = ByteArrayUtils::readString(data,localIndex,&byteRead);
                if ( byteRead == -1 )
                {
                    qDebug() << "VersionData: failed to user name";
                    canReadData = false;
                }

                localIndex += byteRead;
                byteRead = 0;

                QDateTime time = ByteArrayUtils::readDateTime(data,localIndex,&byteRead);
                if ( byteRead == -1 )
                {
                    qDebug() << "VersionData: failed to read time";
                    canReadData = false;
                }

                localIndex += byteRead;
                byteRead = 0;

                QString message = ByteArrayUtils::readString(data,localIndex,&byteRead);
                if ( byteRead == -1 )
                {
                    qDebug() << "VersionData: failed to read message";
                    canReadData = false;
                }

                m_changements.append(Changement(userName,time,message));
                localIndex += byteRead;
            }
            break;
        default:
            localIndex-=nbReadType;
            canReadData=false;
            break;
        }
    }

    return localIndex-index;
}
