#ifndef __VERSIONDATA_H__
#define __VERSIONDATA_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "Data.h"

#include <QString>
#include <QList>

#include "Changement.h"

class VersionData : public Data
{
    enum VersionDataIdentifier
    {
        VDI_VERSION = 11,
        VDI_CHANGEMENT = 12
    };

private:

    int m_version;                      /*!< */
    QList<Changement> m_changements;    /*!< */

public:
    VersionData():Data("VersionData"),m_version(0) {}

    QByteArray data() const;
    int load(const QByteArray &data, int index);

    void addChangement(const Changement& change);

    int version()const { return m_version; }
    const QList<Changement>& getChangesConst()const { return m_changements; }
    QList<Changement>* getChanges() { return &m_changements; }
};

/*! \class VersionData VersionData.h "Types/VersionData.h"
    \brief Data about the different versions of a patient
 */

/*! \enum VersionData::VersionDataIdentifier
    \brief Identifier to recognise the different types of the data in the VersionData segment
 */

/*! \fn VersionData::VersionData()
 */

/*! \fn void VersionData::addChangement(const Changement& change)
    \brief add a new changement
    The version (m_version) will be increased
    \param change the changement information
 */

/*! \fn int VersionData::version()const
    \brief Gets the version number
    \return
 */

/*! \fn const QList<Changement>& VersionData::getChangesConst()const
    \brief Get all the changes as constant
    \return
 */

/*! \fn QList<Changement>* VersionData::getChanges()
    \brief Get all the changes
    \return
 */

#endif
