#ifndef __MAINSCREENWIDGET_H__
#define __MAINSCREENWIDGET_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "QMLWidget.h"

#include <QWidget>
#include <QList>
#include <QString>
#include <QDate>

#include "Types/ButtonList.h"
#include "Types/User.h"

#include "Network/Types/MachineData.h"

#include "Module/ModuleInterface.h"

class Patient;

class QVBoxLayout;
class QMLBarWidget;
class QMLPatientListWidget;
class QMLVersionningWidget;
class QMLEditDataWidget;
class QMLEditUsersWidget;
class QMLEditMachinesWidget;

class QMLChatWidget;

class MainScreenQMLWidget : public QWidget
{
    Q_OBJECT

private:
    static QString PATIENT_LIST_WIDGET_NAME;        /*!< Name for the list of patients */
    static QString VERSIONNING_WIDGET_NAME;         /*!< Name for the list of versions */
    static QString EDITOR_WIDGET_NAME;              /*!< Name for the editor of patients */
    static QString USERSEDITOR_WIDGET_NAME;         /*!< Name for the user editor */
    static QString MACHINESEDITOR_WIDGET_NAME;      /*!< Name for the machines editor */
    static QString CHAT_WIDGET_NAME;                /*!< Name for the char */

    QMap<QString, ModuleInterface*>* m_pPlugins;    /*!< */

    QList<QObject*> m_pPatientNames;                /*!< */
    ButtonList m_buttonList;                        /*!< */

    Patient* m_pPatient;                            /*!< */
    QString m_folder;                               /*!< */
    unsigned int m_userCategory;                    /*!< */

    QVBoxLayout* m_pLayout;                         /*!< */
    QMLBarWidget* m_pQMLBar;                        /*!< */
    QMLPatientListWidget* m_pPatientWidget;         /*!< */
    QMLVersionningWidget* m_pVersionningWidget;     /*!< */
    QMLEditDataWidget* m_pEditorWidget;             /*!< */

    QMLEditUsersWidget* m_pEditUserWidget;          /*!< */
    QMLEditMachinesWidget* m_pEditMachinesWidget;   /*!< */

    QMLChatWidget* m_pChatWidget;                   /*!< */

    void updateData();

public:
    MainScreenQMLWidget(QMap<QString, ModuleInterface*>* pPlugins, QWidget* parent=0);
    ~MainScreenQMLWidget();

    void setPatientNames(const QList<QString>& namesList);
    void setUsersList(const QList<User>& usersList);
    void setMachinesList(const QList<MachineData>& machinesList);
    void setRightLevel(const unsigned int userCategory) { m_userCategory = userCategory; this->updateButtonsList(); }

    Q_SIGNAL void requestPatient(QString patientName);

    Q_SLOT void updateButtonsList();
    Q_SLOT void setPatient(Patient* pPatient);
    Q_SLOT void setOperation(QString operationName, QString operationDate);

    Q_SLOT void constructPlugins();
    Q_SLOT void changeTab(QString tabName);

    Q_SLOT void updatePatient();
    Q_SIGNAL void patientChanged();

    Q_SIGNAL void userNew(QString name, QString password, QString category);
    Q_SIGNAL void deleteUser(QString userName);

    Q_SIGNAL void userNameChanged(QString oldName, QString newName);
    Q_SIGNAL void userCategoryChanged(QString name, QString newCategory);

    Q_SIGNAL void addMachine(QString machineIP, QString machineName);
    Q_SIGNAL void deleteMachine(QString machineIP);

    Q_SLOT void addMessage(QString message);
    Q_SIGNAL void sendMessage(QString message);
};

/*! \class MainScreenQMLWidget MainScreenWidget.h "UI/MainScreenWidget.h"
    \brief Interface to centralise all the interface of MedCenter
 */

/*! \fn MainScreenQMLWidget::MainScreenQMLWidget(QMap<QString, ModuleInterface*>* pPlugins, QWidget* parent=0)
    \param pPlugins list of plugins to use
    \param parent
 */

/*! \fn MainScreenQMLWidget::~MainScreenQMLWidget()
 */

/*! \fn void MainScreenQMLWidget::updateData();
    \brief sends the data to the interface
 */

/*! \fn void MainScreenQMLWidget::setPatientNames(const QList<QString>& namesList);
    \brief Sets the patient names
    \param namesList
 */

/*! \fn void MainScreenQMLWidget::setUsersList(const QList<User>& usersList);
    \brief Sets the patient list
    \param usersList
 */

/*! \fn void MainScreenQMLWidget::setMachinesList(const QList<MachineData>& machinesList);
    \brief Sets the machines list
    \param machinesList
 */

/*! \fn void MainScreenQMLWidget::setRightLevel(const unsigned int userCategory)
    \brief Set the user qualification
    \param userCategory
 */

/*! \fn void MainScreenQMLWidget::requestPatient(QString patientName);
    \brief Signal send when a patient is needed to be shown
    \param patientName
 */

/*! \fn void MainScreenQMLWidget::updateButtonsList();
    \brief Updates the list of buttons
 */

/*! \fn void MainScreenQMLWidget::setPatient(Patient* pPatient);
    \brief Sets a patient to be shown
    \param pPatient
 */

/*! \fn void MainScreenQMLWidget::setOperation(QString operationName, QString operationDate);
    \brief Sets the operation to show
    \param operationName
    \param operationDate
 */

/*! \fn void MainScreenQMLWidget::constructPlugins();
    \brief prepares the plugins
 */

/*! \fn void MainScreenQMLWidget::changeTab(QString tabName);
    \brief Change the widget to display
    \param tabName
 */

/*! \fn void MainScreenQMLWidget::patientChanged();
    \brief A patient has been modified
 */

/*! \fn void MainScreenQMLWidget::userNew(QString name, QString password, QString category);
    \brief Signal send when a new user is needed
    \param name
    \param password
    \param category
 */

/*! \fn void MainScreenQMLWidget::deleteUser(QString userName);
    \brief Signal send when a user is deleted
    \param userName
 */

/*! \fn void MainScreenQMLWidget::userNameChanged(QString oldName, QString newName);
    \brief Signal send when a user name is changed
    \param oldName
    \param newName
 */

/*! \fn void MainScreenQMLWidget::userCategoryChanged(QString name, QString newCategory);
    \brief Signal send when a user category is changed
    \param name
    \param newCategory
 */

/*! \fn void MainScreenQMLWidget::addMachine(QString machineIP, QString machineName);
    \brief Signal send when a new machine is needed
    \param machineIP
    \param machineName
 */

/*! \fn void MainScreenQMLWidget::deleteMachine(QString machineIP);
    \brief Signal send when a machine is removed
    \param machineIP
 */

/*! \fn void MainScreenQMLWidget::addMessage(QString message);
    \brief Add a new message in the chat
    \param message
 */

/*! \fn void MainScreenQMLWidget::sendMessage(QString message);
    \brief Signal send when a new message is needed to be send
    \param message
 */

#endif
