/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "QMLChatWidget.h"

#include <QDeclarativeView>
#include <QDeclarativeContext>

#include "Types/NameObject.h"

QMLChatWidget :: QMLChatWidget(QWidget* parent)
    :QMLWidget(parent)
{

}

QMLChatWidget :: ~QMLChatWidget()
{
    foreach(QObject* pObject, m_messageList)
    {
        delete pObject;
    }
}

void QMLChatWidget :: deleteList()
{
    foreach(QObject* pObject, m_users)
    {
        delete pObject;
    }

    m_users.clear();
}

void QMLChatWidget :: updateUsersList()
{
    m_pView->rootContext()->setContextProperty("userNames", QVariant::fromValue(m_users));
}

bool QMLChatWidget :: updateQML()
{
    if ( m_pQMLObject )
    {
        return connect(m_pQMLObject,SIGNAL(newMessage(QString)),this,SIGNAL(sendMessage(QString)));
    }

    return false;
}

void QMLChatWidget :: addMessage(QString message)
{
    m_messageList.append(new NameObject(message));

    m_pView->rootContext()->setContextProperty("messageList", QVariant::fromValue(m_messageList));

    if ( m_messageList.size() > MESSAGES_BUFFER_SIZE )
    {
        // We remove half the buffer of messages (the oldest)
        for ( unsigned int i = 0 ; i < MESSAGES_BUFFER_SIZE / 2 ; i++ )
        {
            m_messageList.removeFirst();
        }
    }
}

void QMLChatWidget :: setUsersList(const QList<User>& usersList)
{
    this->deleteList();

    foreach(User user, usersList)
    {
        m_users.append(new User(user));
    }

    this->updateUsersList();
}
