#ifndef __QMLEDITDATAWIDGET_H__
#define __QMLEDITDATAWIDGET_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "QMLWidget.h"

#include "UI/Types/FileList.h"

class Patient;

class QMLEditDataWidget : public QMLWidget
{
    Q_OBJECT

private:
    Patient* m_pPatient;        /*!< */
    FileList m_filesList;       /*!< */

    bool updateQML();

    void sendPatientData();

public:
    QMLEditDataWidget(QWidget* parent=0);

    void createPatient();

    void setPatient(Patient* pPatient);

    Q_SIGNAL void newPatient(Patient* pPatient);
    Q_SIGNAL void patientChanged();

    Q_SLOT void setPatientName(QString name);
    Q_SLOT void setPatientAge(QString age);

    Q_SLOT void addOperation();
    Q_SLOT void setOperationName(QString oldOperationName, QString newOperationName);
    Q_SLOT void setOperationDate(QString operationName, QString operationDate);
    Q_SLOT void setOperationObservation(QString operationName, QString observation);

    Q_SLOT void createNewFile(QString category, QString folder);
    Q_SLOT void setFileCategory(QString oldCategory, QString newCategory, QString folderName, QString fileName);
    Q_SLOT void setFileFolder(QString category, QString oldFolder, QString newFolder, QString fileName);
    Q_SLOT void removeFile(QString category, QString folderName, QString fileName);
};

/*! \class QMLEditDataWidget QMLEditDataWidget.h "UI/QMLEditDataWidget.h"
    \brief Interface to edit patient data
 */

/*! \fn QMLEditDataWidget::QMLEditDataWidget(QWidget* parent=0)
    \param parent
 */

/*! \fn void QMLEditDataWidget::sendPatientData()
    \brief Sends the patient data to QML
 */

/*! \fn void QMLEditDataWidget::createPatient();
    \brief Creates a new Patient
 */

/*! \fn void QMLEditDataWidget::setPatient(Patient* pPatient);
    \brief Set the patient to view in the interface
    \param pPatient
 */

/*! \fn void QMLEditDataWidget::newPatient(Patient* pPatient);
    \brief Signal send when a new patient is requested
    \param pPatient
 */

/*! \fn void QMLEditDataWidget::patientChanged();
    \brief Signal send when the patient information are changed
 */

/*! \fn void QMLEditDataWidget::setPatientName(QString name);
    \brief Changes the patient name
    \param name
 */

/*! \fn void QMLEditDataWidget::setPatientAge(QString age);
    \brief Changes the patient age
    \param age
 */

/*! \fn void QMLEditDataWidget::addOperation();
    \brief add a new operation to the patient
 */

/*! \fn void QMLEditDataWidget::setOperationName(QString oldOperationName, QString newOperationName);
    \brief Changes the operation name
    \param oldOperationName
    \param newOperationName
 */

/*! \fn void QMLEditDataWidget::setOperationDate(QString operationName, QString operationDate);
    \brief Changes the operation date
    \param operationName
    \param operationDate
 */

/*! \fn void QMLEditDataWidget::setOperationObservation(QString operationName, QString observation)
    \brief Changes the operation observation
    \param operationName
    \param observation
 */

/*! \fn void QMLEditDataWidget::createNewFile(QString category, QString folder);
    \brief Create a new file of <a>category</a> in <a>folder</a>
    \param category
    \param folder
 */

/*! \fn void QMLEditDataWidget::setFileCategory(QString oldCategory, QString newCategory, QString folderName, QString fileName);
    \brief Changes the file category
    \param oldCategory
    \param newCategory
    \param folderName
    \param fileName
 */

/*! \fn void QMLEditDataWidget::setFileFolder(QString category, QString oldFolder, QString newFolder, QString fileName);
    \brief Changes the file folder
    \param category
    \param oldFolder
    \param newFolder
    \param fileName
 */

/*! \fn void QMLEditDataWidget::removeFile(QString category, QString folderName, QString fileName);
    \brief Removes a file
    \param category
    \param folderName
    \param fileName
 */

#endif
