/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "QMLEditMachinesWidget.h"

#include <QDeclarativeView>
#include <QDeclarativeContext>

QMLEditMachinesWidget :: QMLEditMachinesWidget(QWidget* parent)
    :QMLWidget(parent)
{

}

QMLEditMachinesWidget :: ~QMLEditMachinesWidget()
{
    this->deleteList();
}

void QMLEditMachinesWidget :: deleteList()
{
    foreach(QObject* pObject, m_machines)
    {
        delete pObject;
    }

    m_machines.clear();
}

void QMLEditMachinesWidget :: updateMachinesList()
{
    m_pView->rootContext()->setContextProperty("machineNames", QVariant::fromValue(m_machines));
}

bool QMLEditMachinesWidget :: updateQML()
{
    if ( m_pQMLObject )
    {
        connect(m_pQMLObject,SIGNAL(machineNew(QString, QString)),this,SIGNAL(addMachine(QString, QString)));
        connect(m_pQMLObject,SIGNAL(machineRemoved(QString)),this,SIGNAL(deleteMachine(QString)));

        return true;
    }

    return NULL;
}

void QMLEditMachinesWidget :: setMachineList(const QList<MachineData>& machinesList)
{
    this->deleteList();

    foreach(MachineData machineData, machinesList)
    {
        m_machines.append(new MachineData(machineData));
    }

    this->updateMachinesList();
}



