/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "QMLEditUsersWidget.h"

#include <QDeclarativeView>
#include <QDeclarativeContext>

QMLEditUsersWidget :: QMLEditUsersWidget(QWidget* parent)
    :QMLWidget(parent)
{

}

QMLEditUsersWidget :: ~QMLEditUsersWidget()
{
    this->deleteList();
}

void QMLEditUsersWidget :: deleteList()
{
    foreach(QObject* pObject, m_users)
    {
        delete pObject;
    }

    m_users.clear();
}

void QMLEditUsersWidget :: updateUsersList()
{
    m_pView->rootContext()->setContextProperty("userNames", QVariant::fromValue(m_users));
}

bool QMLEditUsersWidget :: updateQML()
{
    if ( m_pQMLObject )
    {
        connect(m_pQMLObject,SIGNAL(userNew(QString, QString, QString)),this,SIGNAL(userNew(QString, QString, QString)));
        connect(m_pQMLObject,SIGNAL(userNameChanged(QString, QString)),this,SIGNAL(userNameChanged(QString,QString)));
        connect(m_pQMLObject,SIGNAL(userCategoryChanged(QString, QString)),this,SIGNAL(userCategoryChanged(QString,QString)));
        connect(m_pQMLObject,SIGNAL(userRemoved(QString)),this,SIGNAL(deleteUser(QString)));

        return true;
    }

    return NULL;
}

void QMLEditUsersWidget :: setUsersList(const QList<User>& usersList)
{
    this->deleteList();

    foreach(User user, usersList)
    {
        m_users.append(new User(user));
    }

    this->updateUsersList();
}
