#ifndef __QMLWIDGET_H__
#define __QMLWIDGET_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QWidget>

class QDeclarativeView;
class QGraphicsObject;

class QMLWidget : public QWidget
{
    Q_OBJECT

protected:
    QDeclarativeView* m_pView;          /*!< QML View */
    QObject* m_pQMLObject;              /*!< QML Object context */

    virtual bool updateQML()=0;

    void resizeEvent(QResizeEvent* pResizeEvent);

public:

    QMLWidget(QWidget* parent=0);
    virtual ~QMLWidget();

    bool load(const QString& fileName);
};

/*! \class QMLWidget QMLWidget.h "UI/Types/QMLWidget.h"
    \brief Base class for all widget load QML files.
    These widget are also an interface between the QML interface and the rest of the application by handling slots and signals
 */

/*! \fn QMLWidget::QMLWidget(QWidget* parent=0)
    \param parent
 */

/*! \fn virtual QMLWidget::~QMLWidget()
 */

/*! \fn virtual bool QMLWidget::updateQML()=0
    \brief This function is called by load() after the loading of the QML.
    Implementers should connect the slots and signals in it, and also send data to QML file
    (Note: basically, the sending of data to QML should be done before and this will cause showing some warnings, but it is working)
 */

/*! \fn void QMLWidget::resizeEvent(QResizeEvent* pResizeEvent)
    \brief Handles the resize events to cause the QML view to be resized
    \param pResizeEvent information on the resize event
 */

/*! \fn bool QMLWidget::load(const QString& fileName)
    \brief Loads the QML file designed by <a>fileName</a>
    \param fileName the file to load
    \return true if all goes right
 */

#endif
