/*
 * "MedCenter" is an interactive application for hospitals.
 *
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "meddatabase.hpp"

#include <QApplication>
#include <QMessageBox>
#include <QtDebug>

#include "Types/Patient.h"
#include "Types/OperationData.h"

const int MedDatabase::UserDisconnected = 0;
const int MedDatabase::UserConnected = 1;

bool MedDatabase::initDatabase() // Initialise la base de donnée
{
    QSqlDatabase db = QSqlDatabase::addDatabase("QSQLITE");
    db.setDatabaseName(QApplication::applicationDirPath() + "/MedCenter.db");

    if ( !QFile::exists(QApplication::applicationDirPath() + "/MedCenter.db") )
    {
        db.open(); // As creation of the file

        QSqlQuery query;
            if ( query.exec("CREATE TABLE [Computer] ([AdressIp] TEXT, [Name] TEXT)") )
                    if( query.exec("CREATE TABLE [Users] ([Name] TEXT, [Password] TEXT, [Function] INTEGER, [Connected] INTEGER)") )
                            if ( query.exec("CREATE TABLE [Patients] ([Id] INTEGER PRIMARY KEY AUTOINCREMENT, [Name] TEXT, [Room] INTEGER)") )
                                if( query.exec("CREATE TABLE [Items] ([Id] INTEGER PRIMARY KEY AUTOINCREMENT, [IdPatient] INTEGER, [Category] TEXT, [Folder] TEXT, [Name] TEXT, [Path] TEXT)") )
                                        if( query.exec("CREATE TABLE [Versions] ([IdPatient] INTEGER, [messages] TEXT, [version] INT)") )
                                            if( query.exec("CREATE TABLE [Operations] ([Id] INTEGER PRIMARY KEY AUTOINCREMENT, [IdPatient] INTEGER, [Name] TEXT, [Data] TEXT, [Observation] TEXT)") )
                                                if ( MedDatabase::populate() )
                                                    return true;

        // else
        qDebug() << query.lastError().text();
        return false;
    }
    else
    {
        if ( db.open() )
        {
            return true;
        }
    }

    return false;
}

void MedDatabase::closeDatabase() // Ferme la db
{
    QSqlDatabase::database().close();
}

QSqlError MedDatabase::lastError() // Renvoie la dernière erreur de la db
{
    return QSqlDatabase::database().lastError();
}

bool MedDatabase::populate() // Se charge de peupler la base de donnée
{
    // 16ce0a28dba46bc6e211389ce8a27cb89d7bc623 == SHA1("yesyoucant")
    // admin / admin
    // doctor / doctor
    // nurse / nurse

    QSqlQuery query(QSqlDatabase::database());
            if ( query.exec("INSERT INTO Users VALUES('Tortue Caroline', '16ce0a28dba46bc6e211389ce8a27cb89d7bc623', 0, 0)") )
                    if (query.exec("INSERT INTO Users VALUES('Dr Grocha Roucoud', '16ce0a28dba46bc6e211389ce8a27cb89d7bc623', 1, 0)") )
                            if (query.exec("INSERT INTO Users VALUES('Dr Bush Jonnn', '16ce0a28dba46bc6e211389ce8a27cb89d7bc623', 1, 0)") )
                                    if (query.exec("INSERT INTO Users VALUES('Dr GaBi Duvers', '16ce0a28dba46bc6e211389ce8a27cb89d7bc623', 1, 0)") )
                                            if (query.exec("INSERT INTO Users VALUES('Litlwayt Spirit', '16ce0a28dba46bc6e211389ce8a27cb89d7bc623', 2, 0)") )
                                                    if (query.exec("INSERT INTO Users VALUES('Hafidi Abdel', '16ce0a28dba46bc6e211389ce8a27cb89d7bc623', 3, 0)") )
                                                        if (query.exec("INSERT INTO Users VALUES('admin', 'd033e22ae348aeb5660fc2140aec35850c4da997', 1000, 0)") )
                                                            if (query.exec("INSERT INTO Users VALUES('doctor', '1f0160076c9f42a157f0a8f0dcc68e02ff69045b', 100, 0)") )
                                                                if (query.exec("INSERT INTO Users VALUES('nurse', '285f9a003f671c2486a3f87ea1ad5e37699ebc38', 0, 0)") )
                                                                    return true;

    qDebug() << query.lastError().text();
    return false;
}

const QList< User > MedDatabase::listUsers() // Retourne une liste des utilisateurs enrengistré dans la base de donnée
{
    QList< User > result;

    QSqlQuery query(QSqlDatabase::database());
            if (query.exec("SELECT *   FROM Users") )
                    while ( query.next() )
                    {
                            result << User(query.value(0).toString(), // Name
                                                       // query.value(1).toString(), // Password
                                                       query.value(2).toInt(), // Function
                                                       query.value(3).toInt()); // Connected
                    }
            else
                    qDebug() << query.lastError().text();

    return result;
}

bool MedDatabase::connectUser(QString nameUser, QString passwordUser) // Authentifie un utilisateur de manière   ce qu'il récupère ses informations avec la fonction user().
{
    QString passwordHashed = QCryptographicHash::hash(passwordUser.toUtf8(), QCryptographicHash::Sha1).toHex();

    QSqlQuery query(QSqlDatabase::database());
    query.prepare("SELECT Connected FROM Users WHERE Name=:name AND Password=:password");
            query.bindValue(":name", nameUser);
            query.bindValue(":password", passwordHashed);
    if ( query.exec() && query.first() )
    {
            query.prepare("UPDATE Users SET Connected=1 WHERE Name=:name AND Password=:password");
                    query.bindValue(":name", nameUser);
                    query.bindValue(":password", passwordHashed);
            if ( query.exec() )
                    return true;
            else
                    qDebug() << query.lastError().text();
    }
    else
        qDebug() << query.lastError().type() << " -> " <<  query.lastError().text();

    return false;
}

bool MedDatabase::disconnectUser(QString nameUser) // Déconnecte un utilisateur déj  connecté.
{
    QSqlQuery query(QSqlDatabase::database());
    query.prepare("SELECT Connected FROM Users WHERE Name=:name");
            query.bindValue(":name", nameUser);
            if ( query.exec() && query.first() && query.value(0).toInt() == MedDatabase::UserConnected )
            {
                    query.prepare("UPDATE Users SET Connected=0 WHERE Name=:name");
                            query.bindValue(":name", nameUser);
                    if ( query.exec() )
                            return true;
                    else
                            qDebug() << query.lastError().text();
            }
            else
                    qDebug() << query.lastError().text();

    return false;
}

User MedDatabase::user(QString nameUser) // Récupère les informations d'un utilisateur connecté.
{
    QSqlQuery query(QSqlDatabase::database());
    query.prepare("SELECT * FROM Users WHERE Name=:nameUser");
            query.bindValue(":nameUser", nameUser);
    if ( query.exec() && query.first() )
            return User(query.value(0).toString(), //Name
                                    // query.value(1).toString(), // Password
                                    query.value(2).toInt(), // Function
                                    query.value(3).toInt()); // Connected
    else
    {
        qDebug() << query.lastError().text();
    }

    return User(); // invalid user
}

void MedDatabase :: addUser(const QString& name, const QString& password, const QString& category)
{
    QString cryptedPassword = QCryptographicHash::hash(password.toUtf8(), QCryptographicHash::Sha1).toHex();
    QSqlQuery query(QSqlDatabase::database());
    query.prepare("INSERT INTO Users VALUES(:name, :cryptedPassword, :category, 0)");
    query.bindValue(":name",name);
    query.bindValue(":cryptedPassword",cryptedPassword);
    query.bindValue(":category",category);
    if ( !query.exec())
    {
        qDebug() << query.lastError().text();
    }
}

void MedDatabase :: deleteUser(const QString& name)
{
    QSqlQuery deleteQuery(QSqlDatabase::database());
    deleteQuery.prepare("DELETE FROM Users WHERE Name=:name");
    deleteQuery.bindValue(":name",name);
    if ( !deleteQuery.exec() )
    {
        qDebug() << deleteQuery.lastError().text();
    }
}

void MedDatabase :: changeUserName(const QString& oldName, const QString& newName)
{
    QSqlQuery query(QSqlDatabase::database());
    query.prepare("UPDATE Users SET Name=:newName WHERE Name=:name");
            query.bindValue(":name", oldName);
            query.bindValue(":newName", newName);
    if ( !query.exec() )
    {
            qDebug() << query.lastError().text();
    }
}

void MedDatabase :: changeUserCategory(const QString& name, const QString& newCategory)
{
    QSqlQuery query(QSqlDatabase::database());
    query.prepare("UPDATE Users SET Function=:newCategory WHERE Name=:name");
            query.bindValue(":name", name);
            query.bindValue(":newCategory", newCategory);
    if ( !query.exec() )
    {
            qDebug() << query.lastError().text();
    }
}

/*
const QList< Patient > MedDatabase::listPatients() // Retourne une liste des patients
{
        QList< Patient > result;

        QSqlQuery query(QSqlDatabase::database());
                if ( query.exec("SELECT * FROM Patients") )
                {
                        while ( query.next() )
                        {
                                Patient aPatient(query.value(0).toInt(), // Id
                                                                 query.value(1).toString(), // Name
                                                                 query.value(2).toInt()); // Room

                                QSqlQuery query2(QSqlDatabase::database());
                                        query2.prepare("SELECT * FROM Items WHERE IdPatient=:idPatient");
                                                query2.bindValue(":idPatient", aPatient.id);
                                        if ( query2.exec() )
                                                while ( query2.next() )
                                                        aPatient.listData << Item(query2.value(0).toInt(), // Id
                                                                                                          query2.value(1).toInt(), // IdPatient
                                                                                                          static_cast< MedDatabase::FunctionUsers>(query.value(2).toInt()), // Type
                                                                                                          query2.value(3).toString()); // Value
                                        else
                                                qDebug() << query.lastError().text();

                                result << aPatient;
                        }
                }
                else
                        qDebug() << query.lastError().text();

        return result;
}
*/

const QList< SimplePatient > MedDatabase::listPatients() // Retourne une liste des patients
{
    QList< SimplePatient > result;

    QSqlQuery query(QSqlDatabase::database());
    if ( query.exec("SELECT * FROM Patients") )
    {
            while ( query.next() )
            {
                    SimplePatient patient(query.value(1).toString(), // Name
                                          query.value(0).toInt()); // Id

                    result << patient;
            }
    }
    else
            qDebug() << query.lastError().text();

    return result;
}

bool MedDatabase::setPatient(const Patient* pPatient) // Ajoute un patient
{
    if ( pPatient->id() != -1 )
    {
        bool bResult = true;

        {
            QSqlQuery deleteQuery(QSqlDatabase::database());
            deleteQuery.prepare("DELETE FROM Patients WHERE id=:id");
            deleteQuery.bindValue(":id",pPatient->id());
            bResult &= deleteQuery.exec();
        }

        {
            QSqlQuery deleteQuery(QSqlDatabase::database());
            deleteQuery.prepare("DELETE FROM Items WHERE idPatient=:id");
            deleteQuery.bindValue(":id",pPatient->id());
            bResult &= deleteQuery.exec();
        }

        {
            QSqlQuery deleteQuery(QSqlDatabase::database());
            deleteQuery.prepare("DELETE FROM Operations WHERE idPatient=:id");
            deleteQuery.bindValue(":id",pPatient->id());
            bResult &= deleteQuery.exec();
        }

        if (bResult == false)
        {
            qDebug() << "Failed to delete entries of a patient";
        }

    }
    /*
        QSqlQuery query(QSqlDatabase::database());
        query.prepare("INSERT INTO Patients VALUES(NULL, :name, :age)");
                query.bindValue(":name", name);
                query.bindValue(":room", room);
        if ( query.exec() )
                return true;
        else
                qDebug() << query.lastError().text();
*/
    return false;
}

Patient* MedDatabase::patient(int) // Retourne un patient particulier.
{
/*
    QSqlQuery query(QSqlDatabase::database());
    query.prepare("SELECT * FROM Patients WHERE Id=:idPatient");
            query.bindValue(":idPatient", idPatient);
    if ( query.exec() && query.first() )
            return Patient(query.value(0).toInt(), // Id
                                       query.value(1).toString(), // Name
                                       query.value(2).toInt()); // Room
    // TODO
    // age
    // + Item
    // + Version
    else
                    qDebug() << query.lastError().text();*/

    return new Patient(); // invalid patient
}

bool MedDatabase::addItem(int idPatient, const FileData& fileData) // Ajoute un élément médical   un patient
{
    // It seems that SQLLite does not support files ... so we will save the file
    QString folder = "./database/" + QString::number(idPatient) + "/" + fileData.category() + "/" + fileData.folder() + "/";
    QDir itemFolder;
    if ( itemFolder.mkpath(folder) == false )
    {
        qDebug() << "Fail to create the folder to keep the file";
        return false;
    }

    QFile itemFile(folder + fileData.name());
    if ( itemFile.open(QIODevice::WriteOnly) == false )
    {
        qDebug() << "Fail to create the file to keep the FileData";
        return false;
    }

    itemFile.write(fileData.fileData());
    itemFile.close();

    QSqlQuery query(QSqlDatabase::database());
    query.prepare("INSERT INTO Items VALUES(NULL, :idPatient, :Category, :Folder, :Name, :Path)");
            query.bindValue(":idPatient", idPatient);
            query.bindValue(":Category", fileData.category());
            query.bindValue(":Folder", fileData.folder());
            query.bindValue(":Name", fileData.name());
            query.bindValue(":Path", folder + fileData.name());
    if ( query.exec() )
            return true;
    else
            qDebug() << query.lastError().text();

    return false;
}

QList<FileData* > MedDatabase::getPatientItems(int idPatient)
{
    QList<FileData* > listItems;

    QSqlQuery query(QSqlDatabase::database());
    query.prepare("SELECT * FROM Items Where idPatient=:idPatient");
    query.bindValue(":idPatient",idPatient);

    if ( query.exec() )
    {
        while ( query.next() )
        {
            listItems.append(this->item(query.value(0).toInt()));
        }
    }
    else
    {
        qDebug() << query.lastError().text();
    }

    return listItems;
}


FileData* MedDatabase::item(int idItem) // retourne un élément médical
{

    QSqlQuery query(QSqlDatabase::database());
    query.prepare("SELECT * FROM Items WHERE id=:idItem");
            query.bindValue(":idItem", idItem);
    if ( query.exec() && query.first() )
    {
        QString category = query.value(2).toString();
        QString folder = query.value(3).toString();
        QString name = query.value(4).toString();
        QString path = query.value(5).toString();

        QFile dataFile(path);
        if ( dataFile.open(QIODevice::ReadOnly) == false )
        {
            return NULL;
        }

        FileData* pFileData = new FileData(category,name,folder,dataFile.readAll());
        dataFile.close();
        return pFileData;
    }
    else
    {
        qDebug() << query.lastError().text();
        return NULL;
    }
}

bool MedDatabase::setItem(int idItem, int newIdPatient, QString newType, QString newValue) // Modifie un élément médical
{
        QSqlQuery query(QSqlDatabase::database());
                query.prepare("UPDATE Items SET IdPatient=:newIdPatient, Type=:newType, Value=:newValue WHERE Id=:idItem");
                        query.bindValue(":idItem", idItem);
                        query.bindValue(":newIdPatient", newIdPatient);
                        query.bindValue(":newType", newType);
                        query.bindValue(":newValue", newValue);
                if ( query.exec() )
                        return true;
                else
                        qDebug() << query.lastError().text();

        return false;
}

QList<OperationData* > MedDatabase::getPatientOperations(int idPatient)
{
    QList<OperationData* > listOperations;

    QSqlQuery query(QSqlDatabase::database());
    query.prepare("SELECT * FROM Operations Where idPatient=:idPatient");
    query.bindValue(":idPatient",idPatient);

    if ( query.exec() )
    {
        while ( query.next() )
        {
            listOperations.append(new OperationData(query.value(0).toInt(),query.value(1).toString(),QDate::fromString(query.value(2).toString()),query.value(3).toString()));
        }
    }
    else
    {
        qDebug() << query.lastError().text();
    }

    return listOperations;
}

bool MedDatabase::setOperation(const OperationData& operation, int patientId)
{
    if ( operation.id() != -1 )
    {
        QSqlQuery query(QSqlDatabase::database());
        query.prepare("SELECT * FROM Operations Where id=:id");
        query.bindValue(":id",operation.id());
        if ( query.exec() && query.isValid() )
        {
            // We need to do an update since this operation exists
            QSqlQuery updateQuery(QSqlDatabase::database());
            updateQuery.prepare("UPDATE Operations SET Name=:newName, Date=:newDate, Observation=:newObservation WHERE Id=:id");
                    updateQuery.bindValue(":id", operation.id());
                    updateQuery.bindValue(":newName", operation.name());
                    updateQuery.bindValue(":newDate", operation.date().toString());
                    updateQuery.bindValue(":newObservation", operation.observation());
                    if ( updateQuery.exec() )
                    {
                        return true;
                    }
        }
        else
        {
            qDebug() << query.lastError().text();
        }
    }
    else
    {
        // Creation of the entry
        QSqlQuery createQuery(QSqlDatabase::database());
        createQuery.prepare("INSERT INTO Operations VALUES(NULL, :idPatient, :Name, :Date, :Observation)");
                createQuery.bindValue(":idPatient", patientId);
                createQuery.bindValue(":newName", operation.name());
                createQuery.bindValue(":newDate", operation.date().toString());
                createQuery.bindValue(":newObservation", operation.observation());
                if ( createQuery.exec() )
                {
                    QSqlQuery requestQuery(QSqlDatabase::database());
                    requestQuery.prepare("SELECT * FROM Operations Where idPatient=:idPatient AND Name=:name AND Date=:date AND Observation=:observation");
                    requestQuery.bindValue(":idPatient", patientId);
                    requestQuery.bindValue(":name", operation.name());
                    requestQuery.bindValue(":date", operation.date().toString());
                    requestQuery.bindValue(":observation", operation.observation());
                    if ( requestQuery.exec() )
                    {
                        requestQuery.value(0).toInt();
                    }
                    return true;
                }
                else
                {
                    qDebug() << createQuery.lastError().text();
                }
    }


    return false;
}

