/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "MC_3DModule.h"

#include "MC_3DWidget.h"

#include "Types/Patient.h"
#include "Types/ListData.h"
#include "Types/FileData.h"

#include <cassert>

MC_3DModule :: ~MC_3DModule()
{
    delete m_p3DWidget;
}

void MC_3DModule :: createGui(QWidget* parent)
{
    m_pParent = parent;

    m_p3DWidget = new MC_3DWidget(&m_logger,parent);
}

void MC_3DModule :: setPatientData(Patient* pPatient, const QString& folderName)
{
    assert(pPatient);

    m_isVisible = false;
    m_p3DWidget->clearData();

    if ( pPatient->exist("3DData") )
    {
        Data* pData =  pPatient->get("3DData");
        ListData<FileData>* pListData = reinterpret_cast<ListData<FileData>*>(pData);
        if ( pListData )
        {
            foreach(FileData* fd, pListData->dataList())
            {
                if ( fd->folder() == folderName )
                {
                    m_p3DWidget->load3DFile(fd->name(),fd->data());
                    m_isVisible = true;
                }
            }
        }
    }
}

Q_EXPORT_PLUGIN2(3DModule, MC_3DModule)
