#include "mainwindow.h"

#include <QPluginLoader>
#include <QDir>

#include <QDebug>

#include "Module/ModuleInterface.h"

MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent)
{

}

MainWindow::~MainWindow()
{

}

bool MainWindow :: loadPlugins()
{
    bool bResult = true;

    // static plugins loading
    foreach(QObject* pPlugin, QPluginLoader::staticInstances())
    {
        bResult &= loadPlugin(pPlugin);
    }

    // additionnal plugins loading (in ./plugins folder)
    QDir pluginsDir("./plugins");
    foreach (QString fileName, pluginsDir.entryList(QDir::Files))
    {
        qDebug() << "Plugin file: '" << fileName << "'";
        QPluginLoader pluginLoader(pluginsDir.absoluteFilePath(fileName));
        QObject* pPlugin = pluginLoader.instance();
        bResult &= loadPlugin(pPlugin);
    }

    return bResult;
}

bool MainWindow :: loadPlugin(QObject* pPlugin)
{
    if ( pPlugin != NULL )
    {
        ModuleInterface* pModule = qobject_cast<ModuleInterface*>(pPlugin);
        if ( pModule )
        {
            qDebug() << "Added " << pModule->name() << " Logo: " << pModule->imageSource();
            m_pluginsList.push_back(pModule);
            return true;
        }

        qDebug() << "Plugin object type not recognised";
        return false;
    }

    return true;
}

void MainWindow :: createGUI()
{
    if ( m_pluginsList.size() != 0 )
    {
        m_pluginsList.at(0)->createGui(this);
    }
}
