/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "RadioViewerModule.h"

#include <QtGui>

#include <cassert>

#include "RadioViewerWidget.h"

#include "Types/Patient.h"
#include "Types/ListData.h"
#include "Types/FileData.h"

RadioViewerModule :: ~RadioViewerModule()
{
    delete m_pRVWidget;
}

void RadioViewerModule :: createGui(QWidget* parent)
{
    m_pParent = parent;

    m_pRVWidget = new RadioViewerWidget(&m_logger,parent);
}

void RadioViewerModule :: setPatientData(Patient* pPatient, const QString& folderName)
{
    assert(pPatient);

    m_isVisible = false;
    m_pRVWidget->clearData();

    if ( pPatient->exist("RadioData") )
    {
        Data* pData =  pPatient->get("RadioData");
        ListData<FileData>* pListData = reinterpret_cast<ListData<FileData>*>(pData);
        if ( pListData )
        {
            foreach(FileData* fd, pListData->dataList())
            {
                if ( fd->folder() == folderName )
                {
                    m_pRVWidget->loadRadioFile(fd->name(),fd->data());
                    m_isVisible = true;
                }
            }
        }
    }
}

Q_EXPORT_PLUGIN2(radioviewermodule, RadioViewerModule)
