#ifndef __SCAN_H__
#define __SCAN_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QString>
#include <QPixmap>

class QByteArray;

class Scan
{
private:

    QString m_name;         /*!< */
    QPixmap m_scanPixmap;   /*!< */

public:
    static Scan load(const QString& fileName);
    static Scan load(const QString& scanName, const QByteArray& data);

    const QString& name()const { return m_name; }
    const QPixmap& scanPixmap()const { return m_scanPixmap; }
};

/*! \class Scan Scan.h "Scan.h"
 *  \brief Class containing Scan information
 */

/*! \fn static Scan Scan::load(const QString& fileName)
 *  \brief Load a scan from a file
 *  \param fileName the name of the file to load
 *  \return the newly loaded Scan
 *  The fileName is used as Scan name
 *  \sa Scan::load(const QString& scanName, const QByteArray& data)
 */

/*! \fn static Scan Scan::load(const QString& scanName, const QByteArray& data)
 *  \brief Load a scan from a QByteArray
 *  \param scanName the name of the Scan
 *  \param data the data to load
 *  \return the newly loaded Scan
 *  \sa Scan::load(const QString& fileName)
 */

/*! \fn const QString& Scan::name()const
 *  \brief Get the name of the Scan
 *  \return the name of the Scan
 */

/*! \fn const QPixmap& Scan::scanPixmap()const
 *  \brief Get the scan image
 *  \return the scan image
 */

#endif
