#ifndef __SCANLIST_H__
#define __SCANLIST_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QList>

#include "Scan.h"

class QString;
class QPixmap;
class QByteArray;

class ScanList
{
private:
    QPixmap m_invalidPixmap;

    QList<Scan> m_scans;                    /*!< */

    bool isExisting(const QString& name);

public:
    void clear() { m_scans.clear(); }

    bool loadImage(const QString& fileName);
    bool loadImage(const QString& scanName, const QByteArray& data);

    const QPixmap& getScan(unsigned int i)const;
};

/*! \class ScanList ScanList.h "ScanList.h"
 *  \brief List of scans for a patient
 *  This class avoids to load two times the same scan using his name as identifier
 */

/*! \fn bool ScanList::isExisting(const QString& name)
 *  \brief Check if the name is already a name of a scan
 *  \param name the name to check in the list
 *  \return true if the list already contains such name
 */

/*! \fn void ScanList :: clear()
    \brief Removes all the scans available
 */

/*! \fn bool ScanList::loadImage(const QString& fileName)
 *  \brief Loads a scan and add it in the list if the loading succeed
 *  \param fileName the name of the file to load
 *  \return true if the loading succeed
 *  The fileName is used as identifier for this Scan
 *  \sa ScanList::loadImage(const QString& scanName, const QByteArray& data)
 */

/*! \fn bool ScanList::loadImage(const QString& scanName, const QByteArray& data)
 *  \brief Loads a scan and add it in the list if the loading succeed
 *  \param scanName the name of the Scan
 *  \param data the data to load from
 *  \return true if the loading succeed
 *  \sa ScanList::loadImage(const QString& fileName)
 */

/*! \fn const QPixmap& ScanList::getScan(unsigned int i)const
 *  \brief Get the scan at index i
 *  \param i the index of the scan
 *  \return the scan image
 *  If there is no scan in the list, QPixmap() is returned (invalide pixmap)
 *  If the index is > list.size() then the index is modulo to get a valide index
 */

#endif
