/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "ScanViewerWidget.h"

#include <QLabel>
#include <QImageReader>
#include <QList>
#include <QByteArray>
#include <QFileDialog>
#include <QProgressDialog>
#include <QKeyEvent>

#include "ScanList.h"
#include "ScanAnimation.h"

#include "Logger/Logger.h"

ScanViewerWidget :: ScanViewerWidget(Logger* pLogger, QWidget *parent)
    :QWidget(parent),m_pLogger(pLogger)
{
    m_pScanList = new ScanList();
    m_pScanAnimation = new ScanAnimation(m_pScanList);

    m_pDisplayLabel = new QLabel(this);

    connect(m_pScanAnimation,SIGNAL(changed()),this,SLOT(redraw()));

    this->setFocus();
}

ScanViewerWidget :: ~ScanViewerWidget()
{
    delete m_pScanAnimation;
    delete m_pScanList;
}

void ScanViewerWidget :: redraw()
{
    const QPixmap& pixmap = m_pScanAnimation->getScan();
    if ( !pixmap.isNull() )
    {
        m_pDisplayLabel->setPixmap(pixmap);
        m_pDisplayLabel->resize(pixmap.size());
        this->setMinimumSize(pixmap.size());
        this->repaint();
    }
}

void ScanViewerWidget :: keyPressEvent(QKeyEvent* pKeyEvent)
{
    if ( pKeyEvent->key() == Qt::Key_Space )
    {
        m_pScanAnimation->setRunning(!m_pScanAnimation->isRunning());
        pKeyEvent->accept();
    }
    else if ( pKeyEvent->key() == Qt::Key_Left )
    {
        m_pScanAnimation->previousScan();
        pKeyEvent->accept();
    }
    else if ( pKeyEvent->key() == Qt::Key_Right )
    {
        m_pScanAnimation->nextScan();
        pKeyEvent->accept();
    }
}

void ScanViewerWidget :: clearData()
{
    m_pScanList->clear();
}

void ScanViewerWidget :: loadScanFile(const QString& name, const QByteArray& file)
{
    bool bResult = m_pScanList->loadImage(name,file);
    if ( bResult == false )
    {
        m_pLogger->warning("Fail to load '" + name + "'");
    }
}

void ScanViewerWidget :: loadScanFiles()
{
    // Construct the list of extension for the filters
    QList<QByteArray> availableExtensions = QImageReader::supportedImageFormats();
    QString filters = tr("Scan Files (");
    foreach(QByteArray extension, availableExtensions)
    {
        filters.append(" *." + QString(extension));
    }
    filters.append(")");

    QStringList fileNames = QFileDialog::getOpenFileNames(this,tr("Open scan files"),QDir::currentPath(),filters);
    if ( !fileNames.isEmpty() )
    {
        QProgressDialog progressBar(tr("Loading scan files..."),QString(),0,fileNames.count(),this);
        foreach (QString fileName, fileNames)
        {

            bool bResult = m_pScanList->loadImage(fileName);
            if ( bResult == false )
            {
                m_pLogger->warning("Fail to load '" + fileName + "'");
            }

            progressBar.setValue(progressBar.value()+1);
        }
    }
}
