#ifndef __LOGGER_H__
#define __LOGGER_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "Logger_global.h"

#include <QDateTime>

class LOGGERSHARED_EXPORT Logger
{

protected:
    enum LogLevel
    {
        LL_Debug,
        LL_Warning,
        LL_Error
    };

    struct LogMessage
    {
        LogLevel m_logLevel;
        QDateTime m_logTime;
        QString m_message;

        LogMessage(LogLevel logLevel, const QDateTime& logTime, const QString& message)
            :m_logLevel(logLevel),m_logTime(logTime),m_message(message) {}
    };

private:

    static const unsigned int BUFFER_SIZE = 2048;

    void log(LogLevel logLevel, const QString& message);

protected:
    QList<LogMessage> m_messages;

public:
    Logger();
    virtual ~Logger() {}

    void debug(const QString& message);
    void warning(const QString& message);
    void error(const QString& message);

    virtual void dump()=0;
};

#endif
